@@ -1,100 +1,68 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Box::Parser::Perl;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Box::Parser';
 
-use strict;
-use warnings;
-
 use Mail::Message::Field;
 use List::Util 'sum';
 use IO::File;
 
-my $empty_line = qr/^\015?\012?$/;
-
 
 sub init(@)
 {   my ($self, $args) = @_;
+
     $self->SUPER::init($args) or return;
 
-    $self->{MBPP_mode}     = $args->{mode} || 'r';
-    $self->{MBPP_filename} = $args->{filename} || ref $args->{file}
-        or $self->log(ERROR => "Filename or handle required to create a parser."), return;
-
-    $self->start(file => $args->{file});
+    $self->{MBPP_trusted} = $args->{trusted};
+    $self->{MBPP_fix}     = $args->{fix_header_errors};
     $self;
 }
 
-#----------------------
-
-sub filename() { $_[0]->{MBPP_filename} }
-sub openMode() { $_[0]->{MBPP_mode} }
-sub file()     { $_[0]->{MBPP_file} }
-
-#----------------------
-
-sub start(@)
-{   my ($self, %args) = @_;
-    $self->openFile(%args) or return;
-    $self->takeFileInfo;
-
-    $self->log(PROGRESS => "Opened folder ".$self->filename." to be parsed");
+sub pushSeparator($)
+{   my ($self, $sep) = @_;
+    unshift @{$self->{MBPP_separators}}, $sep;
+    $self->{MBPP_strip_gt}++ if $sep eq 'From ';
     $self;
 }
 
-
-sub stop()
+sub popSeparator()
 {   my $self = shift;
-    $self->log(NOTICE  => "Close parser for file ".$self->filename);
-    $self->closeFile;
+    my $sep  = shift @{$self->{MBPP_separators}};
+    $self->{MBPP_strip_gt}-- if $sep eq 'From ';
+    $sep;
 }
-
-
-sub restart()
-{   my $self     = shift;
-    $self->closeFile;
-    $self->openFile(@_) or return;
-    $self->takeFileInfo;
-    $self->log(NOTICE  => "Restarted parser for file ".$self->filename);
-    $self;
-}
-
-
-sub fileChanged()
-{   my $self = shift;
-    my ($size, $mtime) = (stat $self->filename)[7,9];
-    return 0 if !defined $size || !defined $mtime;
-    $size != $self->{MBPP_size} || $mtime != $self->{MBPP_mtime};
-}
-
-
+    
 sub filePosition(;$)
 {   my $self = shift;
-    @_ ? $self->file->seek(shift, 0) : $self->file->tell;
+    @_ ? $self->{MBPP_file}->seek(shift, 0) : $self->{MBPP_file}->tell;
 }
 
+my $empty = qr/^\015?\012?$/;
+
+
 sub readHeader()
 {   my $self  = shift;
-    my $file  = $self->file;
+    my $file  = $self->{MBPP_file};
+
     my @ret   = ($file->tell, undef);
     my $line  = $file->getline;
 
   LINE:
     while(defined $line)
-    {   last LINE if $line =~ $empty_line;
+    {   last LINE if $line =~ $empty;
         my ($name, $body) = split /\s*\:\s*/, $line, 2;
 
         unless(defined $body)
-        {   $self->log(WARNING => "Unexpected end of header in ".$self->filename.":\n $line");
+        {   $self->log(WARNING =>
+                "Unexpected end of header in ".$self->filename.":\n $line");
 
             if(@ret && $self->fixHeaderErrors)
             {   $ret[-1][1] .= ' '.$line;  # glue err line to previous field
@@ -107,7 +75,7 @@ sub readHeader()
             }
         }
 
-        length $body or $body = "\n";
+        $body = "\n" unless length $body;
 
         # Collect folded lines
         while($line = $file->getline)
@@ -126,40 +94,45 @@ sub _is_good_end($)
 {   my ($self, $where) = @_;
 
     # No seps, then when have to trust it.
-    my $sep  = $self->activeSeparator // return 1;
-    my $file = $self->file;
+    my $sep = $self->{MBPP_separators}[0];
+    return 1 unless defined $sep;
+
+    my $file = $self->{MBPP_file};
     my $here = $file->tell;
     $file->seek($where, 0) or return 0;
 
     # Find first non-empty line on specified location.
     my $line = $file->getline;
-    $line    = $file->getline while defined $line && $line =~ $empty_line;
+    $line    = $file->getline while defined $line && $line =~ $empty;
 
     # Check completed, return to old spot.
     $file->seek($here, 0);
-    $line // return 1;
+    return 1 unless defined $line;
 
         substr($line, 0, length $sep) eq $sep
-    && ($sep ne 'From ' || $line =~ m/ (?:19[6-9]|20[0-3])[0-9]\b/ );
+    && ($sep ne 'From ' || $line =~ m/ (?:19[6-9]|20[0-2])[0-9]\b/ );
 }
 
 sub readSeparator()
-{   my $self  = shift;
-    my $sep   = $self->activeSeparator // return ();
-    my $file  = $self->file;
+{   my $self = shift;
+
+    my $sep   = $self->{MBPP_separators}[0];
+    return () unless defined $sep;
+
+    my $file  = $self->{MBPP_file};
     my $start = $file->tell;
 
     my $line  = $file->getline;
-    while(defined $line && $line =~ $empty_line)
-    {   $start = $file->tell;
-        $line  = $file->getline;
+    while(defined $line && $line =~ $empty)
+    {   $start   = $file->tell;
+        $line    = $file->getline;
     }
 
-    $line // return ();
-    $line      =~ s/[\012\015]+$/\n/;
+    return () unless defined $line;
 
-    substr($line, 0, length $sep) eq $sep
-        and return ($start, $line);
+    $line     =~ s/[\012\015\n]+$/\n/g;
+    return ($start, $line)
+        if substr($line, 0, length $sep) eq $sep;
 
     $file->seek($start, 0);
     ();
@@ -167,23 +140,24 @@ sub readSeparator()
 
 sub _read_stripped_lines(;$$)
 {   my ($self, $exp_chars, $exp_lines) = @_;
-    my $seps    = $self->separators;
-    my $file    = $self->file;
+    $exp_lines  = -1 unless defined $exp_lines;
+    my @seps    = @{$self->{MBPP_separators}};
+
+    my $file    = $self->{MBPP_file};
     my $lines   = [];
     my $msgend;
 
-    if(@$seps)
+    if(@seps)
     {   
        LINE:
         while(1)
         {   my $where = $file->getpos;
-            my $line  = $file->getline or last LINE;
+            my $line  = $file->getline
+                or last LINE;
 
-            foreach my $sep (@$seps)
-            {   substr($line, 0, length $sep) eq $sep or next;
-
-                # Some apps fail to escape lines starting with From
-                next if $sep eq 'From ' && $line !~ m/ 19[789][0-9]| 20[0-9][0-9]/;
+            foreach my $sep (@seps)
+            {   next if substr($line, 0, length $sep) ne $sep;
+                next if $sep eq 'From ' && $line !~ m/ 19[789]\d| 20[012]\d/;
 
                 $file->setpos($where);
                 $msgend = $file->tell;
@@ -193,44 +167,47 @@ sub _read_stripped_lines(;$$)
             push @$lines, $line;
         }
 
-        if(@$lines && $lines->[-1] =~ s/\015?\012\z//)
-        {   # Keep an empty line to signal the existence of a preamble, but
-            # remove a second.
-            pop @$lines if @$seps==1 && @$lines > 1 && length($lines->[-1])==0;
+        if(@$lines && $lines->[-1] =~ s/(\r?\n)\z//)
+        {   $file->seek(-length($1), 1);
+            pop @$lines if length($lines->[-1])==0;
         }
     }
     else # File without separators.
-    {   $lines = ref $file eq 'Mail::Box::FastScalar' ? $file->getlines : [ $file->getlines ];
+    {   $lines = ref $file eq 'Mail::Box::FastScalar'
+               ? $file->getlines : [ $file->getlines ];
     }
 
     my $bodyend = $file->tell;
-    if($self->stripGt)
-    {   s/^\>(\>*From\s)/$1/ for @$lines;
-    }
-
-    unless($self->trusted)
-    {   s/\015$// for @$lines;
-        # input is read as binary stream (i.e. preserving CRLF on Windows).
-        # Code is based on this assumption. Removal of CR if not trusted
-        # conflicts with this assumption. [Markus Spann]
+    if($lines)
+    {   if($self->{MBPP_strip_gt})
+        {   s/^\>(\>*From\s)/$1/ for @$lines;
+        }
+        unless($self->{MBPP_trusted})
+        {   s/\015$// for @$lines;
+            # input is read as binary stream (i.e. preserving CRLF on Windows).
+            # Code is based on this assumption. Removal of CR if not trusted
+            # conflicts with this assumption. [Markus Spann]
+        }
     }
+#warn "($bodyend, $msgend, ".@$lines, ")\n";
 
     ($bodyend, $lines, $msgend);
 }
 
 sub _take_scalar($$)
 {   my ($self, $begin, $end) = @_;
-    my $file = $self->file;
+    my $file = $self->{MBPP_file};
     $file->seek($begin, 0);
 
-    my $buffer;
-    $file->read($buffer, $end-$begin);
-    $buffer =~ s/\015//gr;
+    my $return;
+    $file->read($return, $end-$begin);
+    $return =~ s/\015//g;
+    $return;
 }
 
 sub bodyAsString(;$$)
 {   my ($self, $exp_chars, $exp_lines) = @_;
-    my $file  = $self->file;
+    my $file  = $self->{MBPP_file};
     my $begin = $file->tell;
 
     if(defined $exp_chars && $exp_chars>=0)
@@ -239,18 +216,18 @@ sub bodyAsString(;$$)
 
         if($self->_is_good_end($end))
         {   my $body = $self->_take_scalar($begin, $end);
-            $body =~ s/^\>(\>*From\s)/$1/gm if $self->stripGt;
+            $body =~ s/^\>(\>*From\s)/$1/gm if $self->{MBPP_strip_gt};
             return ($begin, $file->tell, $body);
         }
     }
 
     my ($end, $lines) = $self->_read_stripped_lines($exp_chars, $exp_lines);
-    ($begin, $end, join('', @$lines));
+    return ($begin, $end, join('', @$lines));
 }
 
 sub bodyAsList(;$$)
 {   my ($self, $exp_chars, $exp_lines) = @_;
-    my $file  = $self->file;
+    my $file  = $self->{MBPP_file};
     my $begin = $file->tell;
 
     my ($end, $lines) = $self->_read_stripped_lines($exp_chars, $exp_lines);
@@ -259,18 +236,18 @@ sub bodyAsList(;$$)
 
 sub bodyAsFile($;$$)
 {   my ($self, $out, $exp_chars, $exp_lines) = @_;
-    my $file  = $self->file;
+    my $file  = $self->{MBPP_file};
     my $begin = $file->tell;
 
     my ($end, $lines) = $self->_read_stripped_lines($exp_chars, $exp_lines);
 
-    $out->print($_) for @$lines;
+    $out->print($_) foreach @$lines;
     ($begin, $end, scalar @$lines);
 }
 
 sub bodyDelayed(;$$)
 {   my ($self, $exp_chars, $exp_lines) = @_;
-    my $file  = $self->file;
+    my $file  = $self->{MBPP_file};
     my $begin = $file->tell;
 
     if(defined $exp_chars)
@@ -283,49 +260,46 @@ sub bodyDelayed(;$$)
     }
 
     my ($end, $lines) = $self->_read_stripped_lines($exp_chars, $exp_lines);
-    my $chars = sum(map length, @$lines);
+    my $chars = sum(map {length} @$lines);
     ($begin, $end, $chars, scalar @$lines);
 }
 
+sub openFile($)
+{   my ($self, $args) = @_;
+    my $mode = $args->{mode} or die "mode required";
+    my $fh = $args->{file} || IO::File->new($args->{filename}, $mode);
 
-sub openFile(%)
-{   my ($self, %args) = @_;
-
-    my $fh = $self->{MBPP_file} = $args{file} ||
-        IO::File->new($self->filename, $args{mode} || $self->openMode)
-        or return;
+    return unless $fh;
+    $self->{MBPP_file}       = $fh;
 
     $fh->binmode(':raw')
         if $fh->can('binmode') || $fh->can('BINMODE');
 
-    $self->resetSeparators;
+    $self->{MBPP_separators} = [];
+
+#   binmode $fh, ':crlf' if $] < 5.007;  # problem with perlIO
     $self;
 }
 
-
 sub closeFile()
 {   my $self = shift;
-    $self->resetSeparators;
+
+    delete $self->{MBPP_separators};
+    delete $self->{MBPP_strip_gt};
 
     my $file = delete $self->{MBPP_file} or return;
     $file->close;
     $self;
 }
 
+#------------------------------------------
 
-sub takeFileInfo()
+
+sub fixHeaderErrors(;$)
 {   my $self = shift;
-    @$self{ qw/MBPP_size MBPP_mtime/ } = (stat $self->filename)[7,9];
+    @_ ? ($self->{MBPP_fix} = shift) : $self->{MBPP_fix};
 }
 
 #------------------------------------------
 
-#------------------------------------------
-
-sub DESTROY
-{   my $self = shift;
-    $self->stop;
-    $self->SUPER::DESTROY;
-}
-
 1;
