@@ -1,34 +1,30 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
-
-package Mail::Message;
-use vars '$VERSION';
-$VERSION = '3.018_001';
-
-use base 'Mail::Reporter';
-
 use strict;
 use warnings;
 
-use Mail::Message::Part ();
-use Mail::Message::Head::Complete ();
-use Mail::Message::Construct ();
+package Mail::Message;
+use vars '$VERSION';
+$VERSION = '3.001';
 
-use Mail::Message::Body::Lines ();
-use Mail::Message::Body::Multipart ();
-use Mail::Message::Body::Nested ();
+use base 'Mail::Reporter';
+
+use Mail::Message::Part;
+use Mail::Message::Head::Complete;
+use Mail::Message::Construct;
+
+use Mail::Message::Body::Lines;
+use Mail::Message::Body::Multipart;
+use Mail::Message::Body::Nested;
 
 use Carp;
-use Scalar::Util   qw(weaken blessed);
+use Scalar::Util   'weaken';
 
 BEGIN {
     unless($ENV{HARNESS_ACTIVE}) {   # no tests during upgrade
-        # v3 splits Mail::Box in a few distributions
+        # v3 splits Mail::Box is many distributions
 		eval { require Mail::Box };
 		my $v = $Mail::Box::VERSION || 3;
 		$v >= 3 or die "You need to upgrade the Mail::Box module";
@@ -165,7 +161,6 @@ my $default_mailer;
 sub send(@)
 {   my $self = shift;
 
-	# Loosely coupled module
     require Mail::Transport::Send;
 
     my $mailer;
@@ -264,10 +259,13 @@ sub destinations()
 }
 
 
-sub subject() { shift->get('subject') // '' }
+sub subject()
+{   my $subject = shift->get('subject');
+    defined $subject ? $subject : '';
+}
 
 
-sub guessTimestamp() { shift->head->guessTimestamp }
+sub guessTimestamp() {shift->head->guessTimestamp}
 
 
 sub timestamp()
@@ -339,7 +337,7 @@ sub isNested() {shift->body->isNested}
 
 sub contentType()
 {   my $head = shift->head;
-    my $ct   = (defined $head ? $head->get('Content-Type', 0) : undef) // '';
+    my $ct   = (defined $head ? $head->get('Content-Type', 0) : undef) || '';
     $ct      =~ s/\s*\;.*//;
     length $ct ? $ct : 'text/plain';
 }
@@ -498,17 +496,11 @@ my $email_simple_converter;
 sub coerce($@)
 {   my ($class, $message) = @_;
 
-    blessed $message
+    ref $message
         or die "coercion starts with some object";
 
-	return $message
-		if ref $message eq $class;
-
-    if($message->isa(__PACKAGE__)) {
-        $message->head->modified(1);
-        $message->body->modified(1);
-        return bless $message, $class;
-	}
+    return bless $message, $class
+        if $message->isa(__PACKAGE__);
 
     if($message->isa('MIME::Entity'))
     {   unless($mime_entity_converter)
@@ -569,14 +561,14 @@ sub readFromParser($;$)
 {   my ($self, $parser, $bodytype) = @_;
 
     my $head = $self->readHead($parser)
-     || Mail::Message::Head::Complete->new
-          ( message     => $self
-          , field_type  => $self->{MM_field_type}
-          , $self->logSettings
-          );
+            || Mail::Message::Head::Complete->new
+                 ( message     => $self
+                 , field_type  => $self->{MM_field_type}
+                 , $self->logSettings
+                 );
 
     my $body = $self->readBody($parser, $head, $bodytype)
-        or return;
+       or return;
 
     $self->head($head);
     $self->storeBody($body);
@@ -598,11 +590,15 @@ sub readHead($;$)
 }
 
 
+my $mpbody = 'Mail::Message::Body::Multipart';
+my $nbody  = 'Mail::Message::Body::Nested';
+my $lbody  = 'Mail::Message::Body::Lines';
+
 sub readBody($$;$$)
 {   my ($self, $parser, $head, $getbodytype) = @_;
 
     my $bodytype
-      = ! $getbodytype   ? ($self->{MM_body_type} || 'Mail::Message::Body::Lines')
+      = ! $getbodytype   ? ($self->{MM_body_type} || $lbody)
       : ref $getbodytype ? $getbodytype->($self, $head)
       :                    $getbodytype;
 
@@ -610,7 +606,7 @@ sub readBody($$;$$)
     if($bodytype->isDelayed)
     {   $body = $bodytype->new
           ( message => $self
-          , charset => undef     # we do not know, autodetect after transfer decode
+          , charset => 'us-ascii'
           , $self->logSettings
           );
     }
@@ -620,27 +616,27 @@ sub readBody($$;$$)
 
         # Be sure you have acceptable bodies for multiparts and nested.
         if(substr($type, 0, 10) eq 'multipart/' && !$bodytype->isMultipart)
-        {   $bodytype = 'Mail::Message::Body::Multipart';
-        }
-        elsif($type eq 'message/rfc822')
-        {   my $enc = $head->get('Content-Transfer-Encoding') || 'none';
-            $bodytype = 'Mail::Message::Body::Nested'
-                if lc($enc) eq 'none' && ! $bodytype->isNested;
-        }
+        {   $bodytype = $mpbody }
+        elsif($type eq 'message/rfc822' && !$bodytype->isNested)
+        {   $bodytype = $nbody  }
 
         $body = $bodytype->new
-          ( message => $self
-          , checked => $self->{MM_trusted}
-          , charset => undef
-          , $self->logSettings
-          );
+        ( message => $self
+        , checked => $self->{MM_trusted}
+        , charset => 'us-ascii'
+        , $self->logSettings
+        );
 
         $body->contentInfoFrom($head);
     }
 
     my $lines   = $head->get('Lines');  # usually off-by-one
     my $size    = $head->guessBodySize;
-    $body->read($parser, $head, $getbodytype, $size, $lines);
+
+    $body->read
+      ( $parser, $head, $getbodytype,
+      , $size, (defined $lines ? $lines : undef)
+      );
 }
 
 
@@ -663,14 +659,19 @@ sub takeMessageId(;$)
     my $msgid = (@_ ? shift : $self->get('Message-ID')) || '';
 
     if($msgid =~ m/\<([^>]*)\>/s)
-    {   $msgid = $1 =~ s/\s//grs;
+    {   $msgid = $1;
+        $msgid =~ s/\s//gs;
     }
  
-    $self->{MM_message_id} = $msgid || $self->head->createMessageId;
+    $msgid = $self->head->createMessageId
+        unless length $msgid;
+
+    $self->{MM_message_id} = $msgid;
 }
 
 #------------------------------------------
 
+
 sub shortSize(;$)
 {   my $self = shift;
     my $size = shift;
