@@ -1,26 +1,22 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Body;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Reporter';
 
-use strict;
-use warnings;
-
 use Mail::Message::Field;
 use Mail::Message::Body::Lines;
 use Mail::Message::Body::File;
 
 use Carp;
-use Scalar::Util     qw/weaken refaddr blessed/;
+use Scalar::Util     qw/weaken refaddr/;
 use File::Basename   qw/basename/;
 
 use MIME::Types;
@@ -43,19 +39,21 @@ my $body_count = 0;  # to be able to compare bodies for equivalence.
 sub new(@)
 {   my $class = shift;
 
-    $class eq __PACKAGE__
-        or return $class->SUPER::new(@_);
+    return $class->SUPER::new(@_)
+         unless $class eq __PACKAGE__;
 
     my %args  = @_;
 
-    exists $args{file}
-      ? Mail::Message::Body::File->new(@_)
-      : Mail::Message::Body::Lines->new(@_);
+      exists $args{file}
+    ? Mail::Message::Body::File->new(@_)
+    : Mail::Message::Body::Lines->new(@_);
 }
 
 # All body implementations shall implement all of the following!!
+
 sub _data_from_filename(@)   {shift->notImplemented}
 sub _data_from_filehandle(@) {shift->notImplemented}
+sub _data_from_glob(@)       {shift->notImplemented}
 sub _data_from_lines(@)      {shift->notImplemented}
 
 sub init($)
@@ -76,12 +74,12 @@ sub init($)
             $mime ||= $mime_types->mimeTypeOf($filename)
                   || (-T $file ? 'text/plain' : 'application/octet-stream');
         }
-        elsif(ref $file eq 'GLOB' || (blessed $file && $file->isa('IO::Handle')))
-        {   $self->_data_from_filehandle($file) or return;
-        }
+        elsif(ref $file eq 'GLOB')
+        {   $self->_data_from_glob($file) or return }
+        elsif($file->isa('IO::Handle'))
+        {   $self->_data_from_filehandle($file) or return }
         else
-        {   croak "message body: illegal datatype `".ref($file)."' for file option";
-        }
+        {   croak "message body: illegal datatype `".ref($file)."' for file option" }
     }
     elsif(defined(my $data = $args->{data}))
     {
@@ -93,8 +91,7 @@ sub init($)
         {   $self->_data_from_lines($data) or return;
         }
         else
-        {   croak "message body: illegal datatype `".ref($data)."' for data option";
-        }
+        {   croak "message body: illegal datatype `".ref($data)."' for data option" }
     }
     elsif(! $self->isMultipart && ! $self->isNested)
     {   # Neither 'file' nor 'data', so empty body.
@@ -103,8 +100,8 @@ sub init($)
 
     # Set the content info
 
-    my ($transfer, $disp, $descr, $cid, $lang) = @$args{
-       qw/transfer_encoding disposition description content_id language/ };
+    my ($transfer, $disp, $charset, $descr, $cid) = @$args{
+       qw/transfer_encoding disposition charset description content_id/ }; 
 
     if(defined $filename)
     {   $disp //= Mail::Message::Field->new
@@ -119,14 +116,14 @@ sub init($)
     }
 
     if(defined(my $based = $args->{based_on}))
-    {   $mime     //= $based->type;
-        $transfer //= $based->transferEncoding;
-        $disp     //= $based->disposition;
-        $descr    //= $based->description;
-        $lang     //= $based->language;
-        $cid      //= $based->contentId;
+    {   $mime     = $based->type             unless defined $mime;
+        $transfer = $based->transferEncoding unless defined $transfer;
+        $disp     = $based->disposition      unless defined $disp;
+        $descr    = $based->description      unless defined $descr;
+        $cid      = $based->contentId        unless defined $cid;
 
-        $self->{MMB_checked} = exists $args->{checked} ? $args->{checked} : $based->checked;
+        $self->{MMB_checked}
+          = defined $args->{checked} ? $args->{checked} : $based->checked;
     }
     else
     {   $transfer = $args->{transfer_encoding};
@@ -135,20 +132,17 @@ sub init($)
 
     $mime ||= 'text/plain';
     $mime = $self->type($mime);
-
-    my $default_charset = exists $args->{charset} ? $args->{charset} : 'PERL';
-    $mime->attribute(charset => $default_charset)
-        if $default_charset
-        && $mime =~ m!^text/!i
-        && !$mime->attribute('charset');
+    $mime->attribute(charset => ($charset || 'PERL'))
+        if $mime =~ m!^text/!i && !$mime->attribute('charset');
 
     $self->transferEncoding($transfer) if defined $transfer;
     $self->disposition($disp)          if defined $disp;
     $self->description($descr)         if defined $descr;
-    $self->language($lang)             if defined $lang;
     $self->contentId($cid)             if defined $cid;
     $self->type($mime);
 
+    $self->{MMB_eol}   = $args->{eol} || 'NATIVE';
+
     # Set message where the body belongs to.
 
     $self->message($args->{message})
@@ -170,6 +164,37 @@ sub decoded(@)
     $self->encode(charset => 'PERL', transfer_encoding => 'none', @_);
 }
 
+
+sub eol(;$)
+{   my $self = shift;
+    return $self->{MMB_eol} unless @_;
+
+    my $eol  = shift;
+    if($eol eq 'NATIVE')
+    {   $eol = $^O =~ m/^win/i ? 'CRLF'
+             : $^O =~ m/^mac/i ? 'CR'
+             :                   'LF';
+    }
+
+    return $self if $eol eq $self->{MMB_eol} && $self->checked;
+    my $lines = $self->lines;
+    if(@$lines)
+    {   # sometimes texts lack \n on last line
+        $lines->[-1] .= "\n";
+       
+
+           if($eol eq 'CR')   {s/[\015\012]+$/\015/     for @$lines}
+        elsif($eol eq 'LF')   {s/[\015\012]+$/\012/     for @$lines}
+        elsif($eol eq 'CRLF') {s/[\015\012]+$/\015\012/ for @$lines}
+        else
+        {   $self->log(WARNING => "Unknown line terminator $eol ignored");
+            return $self->eol('NATIVE');
+        }
+    }
+
+    (ref $self)->new(based_on => $self, eol => $eol, data => $lines);
+}
+
 #------------------------------------------
 
 
@@ -200,14 +225,16 @@ sub partNumberOf($)
 
 #------------------------------------------
 
+
 sub type(;$)
 {   my $self = shift;
     return $self->{MMB_type} if !@_ && defined $self->{MMB_type};
 
     delete $self->{MMB_mime};
-    my $type = shift // 'text/plain';
+    my $type = defined $_[0] ? shift : 'text/plain';
 
-    $self->{MMB_type} = ref $type ? $type->clone : Mail::Message::Field->new('Content-Type' => $type);
+    $self->{MMB_type} = ref $type ? $type->clone
+      : Mail::Message::Field->new('Content-Type' => $type);
 }
 
 
@@ -217,7 +244,12 @@ sub mimeType()
 
     my $field = $self->{MMB_type};
     my $body  = defined $field ? $field->body : '';
-    $self->{MMB_mime} = length $body ? ($mime_types->type($body) || MIME::Type->new(type => $body)) : $mime_plain;
+
+    return $self->{MMB_mime} = $mime_plain
+       unless length $body;
+
+    $self->{MMB_mime}
+       = $mime_types->type($body) || MIME::Type->new(type => $body);
 }
 
 
@@ -240,7 +272,7 @@ sub description(;$)
 
     my $disp = defined $_[0] ? shift : 'none';
     $self->{MMB_description} = ref $disp ? $disp->clone
-      : Mail::Message::Field->new('Content-Description' => $disp);
+       : Mail::Message::Field->new('Content-Description' => $disp);
 }
 
 
@@ -250,23 +282,8 @@ sub disposition(;$)
 
     my $disp = defined $_[0] ? shift : 'none';
 
-    $self->{MMB_disposition} = blessed $disp ? $disp->clone
-      : Mail::Message::Field->new('Content-Disposition' => $disp);
-}
-
-
-sub language(@)
-{	my $self = shift;
-	return $self->{MMB_lang} if !@_ && $self->{MMB_lang};
-
-	my $langs
-	  = @_ > 1        ? (join ', ', @_)
-	  : blessed $_[0] ? $_[0]
-	  : ref $_[0] eq 'ARRAY' ? (join ', ', @{$_[0]}) : $_[0];
-
-	$self->{MMB_lang} = ! defined $langs || ! length $langs ? undef
-	  : blessed $langs ? $langs->clone
-	  : Mail::Message::Field->new('Content-Language' => $langs);
+    $self->{MMB_disposition} = ref $disp ? $disp->clone
+       : Mail::Message::Field->new('Content-Disposition' => $disp);
 }
 
 
@@ -276,7 +293,7 @@ sub contentId(;$)
 
     my $cid = defined $_[0] ? shift : 'none';
     $self->{MMB_id} = ref $cid ? $cid->clone
-      : Mail::Message::Field->new('Content-ID' => $cid);
+       : Mail::Message::Field->new('Content-ID' => $cid);
 }
 
 
@@ -300,7 +317,7 @@ sub string_unless_carp()
 {   my $self  = shift;
     return $self->string unless (caller)[0] eq 'Carp';
 
-    my $class = ref $self =~ s/^Mail::Message/MM/r;
+    (my $class = ref $self) =~ s/^Mail::Message/MM/;
     "$class object";
 }
 
@@ -322,9 +339,9 @@ sub write(@)
     my $filename = $args{filename};
     die "No filename for write() body" unless defined $filename;
 
-    open my $out, '>', $filename or return;
-    $self->print($out);
-    $out->close or return undef;
+    open OUT, '>', $filename or return;
+    $self->print(\*OUT);
+    close OUT or return undef;
     $self;
 }
 
@@ -352,7 +369,6 @@ sub contentInfoTo($)
     $head->set($self->transferEncoding);
     $head->set($self->disposition);
     $head->set($self->description);
-    $head->set($self->language);
     $head->set($self->contentId);
     $self;
 }
@@ -363,16 +379,15 @@ sub contentInfoFrom($)
 
     $self->type($head->get('Content-Type', 0));
 
-    my ($te, $disp, $desc, $cid, $lang)
+    my ($te, $disp, $desc, $cid)
       = map { my $x = $head->get("Content-$_") || '';
               s/^\s+//,s/\s+$// for $x;
               length $x ? $x : undef
-            } qw/Transfer-Encoding Disposition Description ID Language/;
+            } qw/Transfer-Encoding Disposition Description ID/;
 
     $self->transferEncoding($te);
     $self->disposition($disp);
     $self->description($desc);
-    $self->language($lang);
     $self->contentId($cid);
 
     delete $self->{MMB_mime};
@@ -383,7 +398,7 @@ sub contentInfoFrom($)
 
 sub modified(;$)
 {  my $self = shift;
-   @_ or return $self->isModified;  # compat 2.036
+   return $self->isModified unless @_;  # compat 2.036
    $self->{MMB_modified} = shift;
 }
 
@@ -393,7 +408,7 @@ sub isModified() { shift->{MMB_modified} }
 
 sub fileLocation(;@)
 {   my $self = shift;
-    @_ or return @$self{ qw/MMB_begin MMB_end/ };
+    return @$self{ qw/MMB_begin MMB_end/ } unless @_;
     @$self{ qw/MMB_begin MMB_end/ } = @_;
 }
 
@@ -411,24 +426,25 @@ sub load() {shift}
 #------------------------------------------
 
 
-my @in_encode = qw/check encode encoded eol isBinary isText unify dispositionFilename/;
-my %in_module = map +($_ => 'encode'), @in_encode;
+my @in_encode = qw/check encode encoded eol isBinary isText unify
+                   dispositionFilename/;
+my %in_module = map { ($_ => 'encode') } @in_encode;
 
 sub AUTOLOAD(@)
 {   my $self  = shift;
     our $AUTOLOAD;
-    my $call = $AUTOLOAD =~ s/.*\:\://gr;
+    (my $call = $AUTOLOAD) =~ s/.*\:\://g;
 
     my $mod = $in_module{$call} || 'construct';
-    if($mod eq 'encode') { require Mail::Message::Body::Encode    }
-    else                 { require Mail::Message::Body::Construct }
+    if($mod eq 'encode'){ require Mail::Message::Body::Encode    }
+    else                { require Mail::Message::Body::Construct }
 
     no strict 'refs';
     return $self->$call(@_) if $self->can($call);  # now loaded
 
-	# AUTOLOAD inheritance is a pain
-	confess "Method $call() is not defined for a ", ref $self;
-}
+    # Try parental AUTOLOAD
+    Mail::Reporter->$call(@_);
+}   
 
 #------------------------------------------
 
