@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Body::File;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Body';
 
-use strict;
-use warnings;
-
 use Mail::Box::Parser;
 use Mail::Message;
 
@@ -26,16 +22,27 @@ use File::Copy qw/copy/;
 sub _data_from_filename(@)
 {   my ($self, $filename) = @_;
 
-    open my $in, '<:raw', $filename
-        or $self->log(ERROR => "Unable to read file $filename for message body file: $!"), return;
+    local $_;
+    local (*IN, *OUT);
+
+    unless(open IN, '<:raw', $filename)
+    {   $self->log(ERROR =>
+            "Unable to read file $filename for message body file: $!");
+        return;
+    }
 
     my $file   = $self->tempFilename;
-    open my $out, '>:raw', $file
-        or $self->log(ERROR => "Cannot write to temporary body file $file: $!"), return;
+    unless(open OUT, '>:raw', $file)
+    {   $self->log(ERROR => "Cannot write to temporary body file $file: $!");
+        return;
+    }
 
     my $nrlines = 0;
-    local $_;
-    while(<$in>) { $out->print($_); $nrlines++ }
+    while(<IN>) { print OUT; $nrlines++ }
+
+    close OUT;
+    close IN;
+
     $self->{MMBF_nrlines} = $nrlines;
     $self;
 }
@@ -45,27 +52,59 @@ sub _data_from_filehandle(@)
     my $file    = $self->tempFilename;
     my $nrlines = 0;
 
-    open my $out, '>:raw', $file
-        or $self->log(ERROR => "Cannot write to temporary body file $file: $!"), return;
+    local *OUT;
 
-    local $_;
-    while(<$fh>)
-    {   $out->print($_);
+    unless(open OUT, '>:raw', $file)
+    {   $self->log(ERROR => "Cannot write to temporary body file $file: $!");
+        return;
+    }
+
+    while(my $l = $fh->getline)
+    {   print OUT $l;
         $nrlines++;
     }
+    close OUT;
+
+    $self->{MMBF_nrlines} = $nrlines;
+    $self;
+}
+
+sub _data_from_glob(@)
+{   my ($self, $fh) = @_;
+    my $file    = $self->tempFilename;
+    my $nrlines = 0;
+
+    local $_;
+    local *OUT;
+
+    unless(open OUT, '>:raw', $file)
+    {   $self->log(ERROR => "Cannot write to temporary body file $file: $!");
+        return;
+    }
+
+    while(<$fh>)
+    {   print OUT;
+        $nrlines++;
+    }
+    close OUT;
 
     $self->{MMBF_nrlines} = $nrlines;
     $self;
 }
 
 sub _data_from_lines(@)
-{   my ($self, $lines) = @_;
+{   my ($self, $lines)  = @_;
     my $file = $self->tempFilename;
 
-    open my $out, '>:raw', $file
-        or $self->log(ERROR => "Cannot write to $file: $!"), return;
+    local *OUT;
 
-    $out->print(@$lines);
+    unless(open OUT, '>:raw', $file)
+    {   $self->log(ERROR => "Cannot write to $file: $!");
+        return;
+    }
+
+    print OUT @$lines;
+    close OUT;
 
     $self->{MMBF_nrlines} = @$lines;
     $self;
@@ -75,7 +114,7 @@ sub clone()
 {   my $self  = shift;
     my $clone = ref($self)->new(based_on => $self);
 
-    copy $self->tempFilename, $clone->tempFilename
+    copy($self->tempFilename, $clone->tempFilename)
        or return;
 
     $clone->{MMBF_nrlines} = $self->{MMBF_nrlines};
@@ -92,11 +131,14 @@ sub nrLines()
     my $file    = $self->tempFilename;
     my $nrlines = 0;
 
-    open my $in, '<:raw', $file
+    local $_;
+    local *IN;
+
+    open IN, '<:raw', $file
         or die "Cannot read from $file: $!\n";
 
-    local $_;
-    $nrlines++ while <$in>;
+    $nrlines++ while <IN>;
+    close IN;
 
     $self->{MMBF_nrlines} = $nrlines;
 }
@@ -107,7 +149,7 @@ sub size()
 {   my $self = shift;
 
     return $self->{MMBF_size}
-        if exists $self->{MMBF_size};
+       if exists $self->{MMBF_size};
 
     my $size = eval { -s $self->tempFilename };
 
@@ -119,22 +161,34 @@ sub size()
 
 sub string()
 {   my $self = shift;
+
     my $file = $self->tempFilename;
-    open my $in, '<:raw', $file
+
+    local *IN;
+
+    open IN, '<:raw', $file
         or die "Cannot read from $file: $!\n";
 
-    join '', $in->getlines;
+    my $return = join '', <IN>;
+    close IN;
+
+    $return;
 }
 
 sub lines()
 {   my $self = shift;
+
     my $file = $self->tempFilename;
 
-    open my $in, '<:raw', $file
+    local *IN;
+    open IN, '<:raw', $file
         or die "Cannot read from $file: $!\n";
 
-    my $r = $self->{MMBF_nrlines} = [ $in->getlines ];
-    wantarray ? @$r: $r;
+    my @r = <IN>;
+    close IN;
+
+    $self->{MMBF_nrlines} = @r;
+    wantarray ? @r: \@r;
 }
 
 sub file()
@@ -147,11 +201,15 @@ sub print(;$)
     my $fh   = shift || select;
     my $file = $self->tempFilename;
 
-    open my $in, '<:raw', $file
+    local $_;
+    local *IN;
+
+    open IN, '<:raw', $file
         or croak "Cannot read from $file: $!\n";
 
-    $fh->print($_) while <$in>;
-    $in->close;
+    if(ref $fh eq 'GLOB') {print $fh $_ while <IN>}
+    else                  {$fh->print($_) while <IN>}
+    close IN;
 
     $self;
 }
@@ -160,11 +218,13 @@ sub read($$;$@)
 {   my ($self, $parser, $head, $bodytype) = splice @_, 0, 4;
     my $file = $self->tempFilename;
 
-    open my $out, '>:raw', $file
+    local *OUT;
+
+    open OUT, '>:raw', $file
         or die "Cannot write to $file: $!.\n";
 
-    (my $begin, my $end, $self->{MMBF_nrlines}) = $parser->bodyAsFile($out, @_);
-    $out->close;
+    (my $begin, my $end, $self->{MMBF_nrlines}) = $parser->bodyAsFile(\*OUT,@_);
+    close OUT;
 
     $self->fileLocation($begin, $end);
     $self;
@@ -176,6 +236,7 @@ sub endsOnNewline() { shift->size==0 }
 
 #------------------------------------------
 
+
 sub tempFilename(;$)
 {   my $self = shift;
 
@@ -186,6 +247,9 @@ sub tempFilename(;$)
 
 #------------------------------------------
 
+
 sub DESTROY { unlink shift->tempFilename }
 
+#------------------------------------------
+
 1;
