@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Body::Multipart;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Body';
 
-use strict;
-use warnings;
-
 use Mail::Message::Body::Lines;
 use Mail::Message::Part;
 
@@ -52,14 +48,17 @@ sub init($)
     
     if($based)
     {   $self->boundary($args->{boundary} || $based->boundary);
-        $self->{MMBM_preamble} = $preamble // $based->preamble;
+        $self->{MMBM_preamble}
+            = defined $preamble ? $preamble : $based->preamble;
 
         $self->{MMBM_parts}
             = @parts ? \@parts
-            : !$args->{parts} && $based->isMultipart ? [ $based->parts('ACTIVE') ]
+            : !$args->{parts} && $based->isMultipart
+                     ? [ $based->parts('ACTIVE') ]
             :          [];
 
-        $self->{MMBM_epilogue} = $epilogue // $based->epilogue;
+        $self->{MMBM_epilogue}
+            = defined $epilogue ? $epilogue : $based->epilogue;
     }
     else
     {   $self->boundary($args->{boundary} ||$self->type->attribute('boundary'));
@@ -106,10 +105,7 @@ sub nrLines()
     }
 
     if(my $epilogue = $self->epilogue)
-    {   # nrLines should match mbox counts, which is a bit
-        # unclear w.r.t. the \n after a multipart separator
-        # line.
-        $nr += $epilogue->nrLines -1;
+    {   $nr += $epilogue->nrLines;
     }
 
     $nr;
@@ -183,13 +179,24 @@ sub print(;$)
         $count++;
     }
 
-    foreach my $part ($self->parts('ACTIVE'))
-    {   $out->print("\n") if $count++;
-        $out->print("--$boundary\n");
-        $part->print($out);
+    if(ref $out eq 'GLOB')
+    {   foreach my $part ($self->parts('ACTIVE'))
+        {   print $out "\n" if $count++;
+            print $out "--$boundary\n";
+            $part->print($out);
+        }
+        print $out "\n" if $count++;
+        print $out "--$boundary--";
+    }
+    else
+    {   foreach my $part ($self->parts('ACTIVE'))
+        {   $out->print("\n") if $count++;
+            $out->print("--$boundary\n");
+            $part->print($out);
+        }
+        $out->print("\n") if $count++;
+        $out->print("--$boundary--");
     }
-    $out->print("\n") if $count++;
-    $out->print("--$boundary--");
 
     if(my $epilogue = $self->epilogue)
     {   $out->print("\n");
@@ -227,7 +234,7 @@ sub read($$$$)
     my $boundary   = $self->boundary;
 
     $parser->pushSeparator("--$boundary");
-    my @msgopts    = $self->logSettings;
+    my @msgopts    = ($self->logSettings);
 
     my $te;
     $te = lc $1
@@ -240,30 +247,31 @@ sub read($$$$)
 
     # Get preamble.
     my $headtype = ref $head;
-    my $begin    = $parser->filePosition;
-    my $preamble = Mail::Message::Body::Lines->new(@msgopts, @sloppyopts)->read($parser, $head);
 
-    $preamble->nrLines or undef $preamble;
-    $self->{MMBM_preamble} = $preamble if defined $preamble;
+    my $begin    = $parser->filePosition;
+    my $preamble = Mail::Message::Body::Lines->new(@msgopts, @sloppyopts)
+       ->read($parser, $head);
+
+    $preamble->nrLines
+        or undef $preamble;
+
+    $self->{MMBM_preamble} = $preamble
+        if defined $preamble;
 
     # Get the parts.
 
-    my ($has_epilogue, @parts);
+    my @parts;
     while(my $sep = $parser->readSeparator)
-    {   if($sep =~ m/^--\Q$boundary\E--[ \t]*\n?/)
-        {   # Per RFC 2046, a CRLF after the close-delimiter marks the presence
-            # of an epilogue.  Preserve the epilogue, even if empty, so that the
-            # printed multipart body will also have the CRLF.
-            # This, however, is complicated w.r.t. mbox folders.
-            $has_epilogue = $sep =~ /\n/;
-            last;
-        }
+    {   last if $sep eq "--$boundary--\n";
 
-        my $part = Mail::Message::Part->new(@msgopts, container => $self);
-        $part->readFromParser($parser, $bodytype)
-            or last;
+        my $part = Mail::Message::Part->new
+         ( @msgopts
+         , container => $self
+         );
 
-        push @parts, $part if $part->head->names || $part->body->size;
+        last unless $part->readFromParser($parser, $bodytype);
+        push @parts, $part
+            if $part->head->names || $part->body->size;
     }
     $self->{MMBM_parts} = \@parts;
 
@@ -279,7 +287,7 @@ sub read($$$$)
             :                      $begin;
     $self->fileLocation($begin, $end);
 
-    $has_epilogue || $epilogue->nrLines
+   $epilogue->nrLines
         or undef $epilogue;
 
     $self->{MMBM_epilogue} = $epilogue
@@ -290,6 +298,7 @@ sub read($$$$)
 
 #------------------------------------------
 
+
 sub foreachComponent($)
 {   my ($self, $code) = @_;
     my $changes  = 0;
@@ -377,11 +386,11 @@ sub parts(;$)
     my $what  = shift;
     my @parts = @{$self->{MMBM_parts}};
 
-      $what eq 'RECURSE' ? (map $_->parts('RECURSE'), @parts)
+      $what eq 'RECURSE' ? (map {$_->parts('RECURSE')} @parts)
     : $what eq 'ALL'     ? @parts
-    : $what eq 'DELETED' ? (grep $_->isDeleted, @parts)
-    : $what eq 'ACTIVE'  ? (grep !$_->isDeleted, @parts)
-    : ref $what eq 'CODE'? (grep $what->($_), @parts)
+    : $what eq 'DELETED' ? (grep {$_->isDeleted} @parts)
+    : $what eq 'ACTIVE'  ? (grep {not $_->isDeleted} @parts)
+    : ref $what eq 'CODE'? (grep {$what->($_)} @parts)
     : ($self->log(ERROR => "Unknown criterium $what to select parts."), return ());
 }
 
@@ -390,15 +399,13 @@ sub part($) { shift->{MMBM_parts}[shift] }
 
 sub partNumberOf($)
 {   my ($self, $part) = @_;
+    my @parts = $self->parts('ACTIVE');
     my $msg   = $self->message;
     unless($msg)
     {   $self->log(ERROR => 'multipart is not connected');
         return 'ERROR';
     }
-
     my $base  = $msg->isa('Mail::Message::Part') ? $msg->partNumber.'.' : '';
-
-    my @parts = $self->parts('ACTIVE');
     foreach my $partnr (0..@parts)
     {   return $base.($partnr+1)
             if $parts[$partnr] == $part;
