@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Body::Nested;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Body';
 
-use strict;
-use warnings;
-
 use Mail::Message::Body::Lines;
 use Mail::Message::Part;
 
@@ -79,7 +75,7 @@ sub print(;$)
 
 sub partNumberOf($)
 {   my ($self, $part) = @_;
-    $self->message->partNumber || '1';
+    $self->message->partNumber;
 }
 
 
@@ -130,7 +126,6 @@ sub moveLocation($)
     $self;
 }
 
-#-------------------------
 
 sub nested() { shift->{MMBN_nested} }
 
