@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Body::String;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Body';
 
-use strict;
-use warnings;
-
 use Carp;
 use Mail::Box::FastScalar;
 
@@ -27,11 +23,16 @@ sub _data_from_filename(@)
 {   my ($self, $filename) = @_;
 
     delete $self->{MMBS_nrlines};
-    open my $in, '<:raw', $filename
-        or $self->log(ERROR => "Unable to read file $filename for message body scalar: $!"), return;
 
-    my @lines = $in->getlines;
-    $in->close;
+    local *IN;
+    unless(open IN, '<', $filename)
+    {   $self->log(ERROR =>
+            "Unable to read file $filename for message body scalar: $!");
+        return;
+    }
+
+    my @lines = <IN>;
+    close IN;
 
     $self->{MMBS_nrlines} = @lines;
     $self->{MMBS_scalar}  = join '', @lines;
@@ -53,6 +54,14 @@ sub _data_from_filehandle(@)
     $self;
 }
 
+sub _data_from_glob(@)
+{   my ($self, $fh) = @_;
+    my @lines = <$fh>;
+    $self->{MMBS_nrlines} = @lines;
+    $self->{MMBS_scalar}  = join '', @lines;
+    $self;
+}
+
 sub _data_from_lines(@)
 {   my ($self, $lines) = @_;
     $self->{MMBS_nrlines} = @$lines unless @$lines==1;
@@ -88,7 +97,8 @@ sub file() { Mail::Box::FastScalar->new(\shift->{MMBS_scalar}) }
 sub print(;$)
 {   my $self = shift;
     my $fh   = shift || select;
-    $fh->print($self->{MMBS_scalar});
+    if(ref $fh eq 'GLOB') { print $fh $self->{MMBS_scalar} }
+    else                  { $fh->print($self->{MMBS_scalar}) }
     $self;
 }
 
