@@ -1,18 +1,23 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
+use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 
-use strict;
-use warnings;
+use Mail::Message::Head::Complete;
+use Mail::Message::Body::Lines;
+use Mail::Message::Body::Multipart;
+
+use Mail::Address;
+use Carp;
+use Scalar::Util 'blessed';
+use IO::Lines;
 
 
 our %locations =
@@ -48,7 +53,7 @@ our %locations =
 sub AUTOLOAD(@)
 {   my $self  = shift;
     our $AUTOLOAD;
-    my $call = $AUTOLOAD =~ s/.*\:\://gr;
+    (my $call = $AUTOLOAD) =~ s/.*\:\://g;
 
     if(my $mod = $locations{$call})
     {   eval "require Mail::Message::Construct::$mod";
