@@ -1,19 +1,15 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
+use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 
-use strict;
-use warnings;
-
 use Mail::Message::Head::Complete;
 use Mail::Message::Body::Lines;
 use Mail::Message::Body::Multipart;
@@ -30,12 +26,12 @@ my @default_rules =
 
 sub rebuild(@)
 {   my ($self, %args) = @_;
-    my $keep  = delete $args{keep_message_id};
-
+ 
     # Collect the rules to be run
-    my @rules = $args{rules} ? @{delete $args{rules}} : @default_rules;
-    unshift @rules, @{delete $args{extra_rules}} if $args{extra_rules};
-    unshift @rules, @{delete $args{extraRules}}  if $args{extraRules}; #old name
+
+    my @rules   = $args{rules} ? @{$args{rules}} : @default_rules;
+    unshift @rules, @{$args{extra_rules}} if $args{extra_rules};
+    unshift @rules, @{$args{extraRules}}  if $args{extraRules}; #old name
 
     foreach my $rule (@rules)
     {   next if ref $rule;
@@ -47,7 +43,7 @@ sub rebuild(@)
 
     # Start off with the message
 
-    my $rebuild = $self->recursiveRebuildPart($self, %args, rules => \@rules)
+    my $rebuild = $self->recursiveRebuildPart($self, rules => \@rules)
         or return;
 
     # Be sure we end-up with a message
@@ -60,7 +56,7 @@ sub rebuild(@)
         $rebuild = $clone;
     }
 
-    $keep or $rebuild->takeMessageId;
+    $args{keep_message_id} or $rebuild->takeMessageId;
     $rebuild;
 }
 
@@ -124,8 +120,8 @@ sub descendMultiparts($@)
     foreach my $part ($body->parts)
     {   my $new = $self->recursiveRebuildPart($part, %args);
         if(!defined $new)  { $changed++ }
-        elsif($new==$part) { push @newparts, $part }
-        else               { push @newparts, $new; $changed++ }
+	elsif($new==$part) { push @newparts, $part }
+	else               { push @newparts, $new; $changed++ }
     }
 
     $changed or return $part;
@@ -142,7 +138,7 @@ sub descendMultiparts($@)
 
     $rebuild->body($newbody);   # update Content-* lines
     $rebuild;
-}
+ }
 
 sub descendNested($@)
 {   my ($self, $part, %args) = @_;
@@ -189,7 +185,7 @@ sub replaceDeletedParts($@)
 # The more complex rules
 
 sub removeHtmlAlternativeToText($@)
-{   my ($self, $part) = @_;
+{   my ($self, $part, %args) = @_;
     $part->body->mimeType eq 'text/html'
         or return $part;
 
@@ -208,7 +204,7 @@ sub removeHtmlAlternativeToText($@)
 }
 
 sub removeExtraAlternativeText($@)
-{   my ($self, $part) = @_;
+{   my ($self, $part, %args) = @_;
 
     my $container = $part->container;
     $container && $container->mimeType eq 'multipart/alternative'
@@ -225,7 +221,7 @@ sub textAlternativeForHtml($@)
 
     my $hft = 'Mail::Message::Convert::HtmlFormatText';
     unless(defined $has_hft)
-    {   eval "require $hft";
+    {   eval "require Mail::Message::Convert::HtmlFormatText";
         $has_hft = $hft->can('format');
     }
 
@@ -244,7 +240,7 @@ sub textAlternativeForHtml($@)
     # Create the plain part
 
     my $html_body  = $part->body;
-    my $plain_body = $hft->new(%args)->format($html_body);
+    my $plain_body = $hft->new->format($html_body);
 
     my $plain_part = Mail::Message::Part->new(container => undef);
     $plain_part->body($plain_body);
@@ -280,8 +276,7 @@ sub recursiveRebuildPart($@)
 
   RULES:
     foreach my $rule (@{$args{rules}})
-    {   my %params  = ( %args, %{$args{$rule} || {}} );
-        my $rebuild = $self->$rule($part, %params)
+    {   my $rebuild = $self->$rule($part, %args)
             or return undef;
 
         if($part != $rebuild)
