@@ -1,19 +1,15 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
+use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 
-use strict;
-use warnings;
-
 use Mail::Message::Body::Multipart;
 use Mail::Address;
 use Scalar::Util 'blessed';
@@ -88,7 +84,8 @@ sub reply(@)
     }
 
     # To whom to send
-    my $to = delete $args{To} || $mainhead->get('reply-to') || $mainhead->get('from');
+    my $to = delete $args{To}
+          || $mainhead->get('reply-to') || $mainhead->get('from');
     defined $to or return;
 
     # Add Cc
@@ -134,17 +131,29 @@ sub reply(@)
     if($include eq 'NO') {$total = $body}
     elsif($include eq 'INLINE')
     {   my $signature = $args{signature};
-        $signature    = $signature->body
-            if defined $signature && $signature->isa('Mail::Message');
+        $signature = $signature->body
+           if defined $signature && $signature->isa('Mail::Message');
 
-        $total = $body->concatenate($prelude, $body, $postlude, (defined $signature ? "-- \n" : undef), $signature);
+        $total = $body->concatenate
+          ( $prelude, $body, $postlude
+          , (defined $signature ? "-- \n" : undef), $signature
+          );
     }
-    elsif($include eq 'ATTACH')
-    {   my $intro = $prelude->concatenate($prelude, ["\n", "[Your message is attached]\n"], $postlude);
-        $total = Mail::Message::Body::Multipart->new(parts => [ $intro, $body, $args{signature} ]);
+    if($include eq 'ATTACH')
+    {
+         my $intro = $prelude->concatenate
+           ( $prelude
+           , [ "\n", "[Your message is attached]\n" ]
+           , $postlude
+           );
+
+        $total = Mail::Message::Body::Multipart->new
+         ( parts => [ $intro, $body, $args{signature} ]
+        );
     }
 
     my $msgtype = $args{message_type} || 'Mail::Message';
+
     my $reply   = $msgtype->buildFromBody
       ( $total
       , From    => $from || 'Undisclosed senders:;'
@@ -161,6 +170,7 @@ sub reply(@)
         for sort grep /^[A-Z]/, keys %args;
 
     # Ready
+
     $self->log(PROGRESS => 'Reply created from '.$origid);
     $self->label(replied => 1);
     $reply;
@@ -184,7 +194,7 @@ sub replySubject($)
 
         for(shift @subject)
         {   while( /\bRe(?:\[\s*(\d+)\s*\]|\b)/g )
-            {   $re_count += ($1 // 1);
+            {   $re_count += defined $1 ? $1 : 1;
             }
         }
     }
@@ -200,27 +210,32 @@ sub replySubject($)
     # Create the new subject string.
 
     my $text = (join ':', @subject) || 'your mail';
-    s/^\s+//, s/\s+$// for $text;
+    for($text)
+    {  s/^\s+//;
+       s/\s+$//;
+    }
 
     $re_count==1 ? "Re: $text" : "Re[$re_count]: $text";
 }
 
+#------------------------------------------
 
 
 sub replyPrelude($)
 {   my ($self, $who) = @_;
+ 
     $who = $who->[0] if ref $who eq 'ARRAY';
 
     my $user
-      = !defined $who                     ? undef
-      : !ref $who                         ? (Mail::Address->parse($who))[0]
-      : $who->isa('Mail::Message::Field') ? ($who->addresses)[0]
-      :                                     $who;
+     = !defined $who                     ? undef
+     : !ref $who                         ? (Mail::Address->parse($who))[0]
+     : $who->isa('Mail::Message::Field') ? ($who->addresses)[0]
+     :                                     $who;
 
     my $from
-      = ref $user && $user->isa('Mail::Address')
-      ? ($user->name || $user->address || $user->format)
-      : 'someone';
+     = ref $user && $user->isa('Mail::Address')
+     ? ($user->name || $user->address || $user->format)
+     : 'someone';
 
     my $time = gmtime $self->timestamp;
     "On $time, $from wrote:\n";
