@@ -1,19 +1,15 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
+use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 
-use strict;
-use warnings;
-
 use IO::Lines;
 
 
@@ -22,6 +18,8 @@ sub string()
     $self->head->string . $self->body->string;
 }
 
+#------------------------------------------
+
 
 sub lines()
 {   my $self = shift;
@@ -31,6 +29,8 @@ sub lines()
     wantarray ? @lines : \@lines;
 }
 
+#------------------------------------------
+
 
 sub file()
 {   my $self = shift;
@@ -63,7 +63,7 @@ sub printStructure(;$$)
     my $deleted = $self->label('deleted') ? ', deleted' : '';
 
     my $text    = "$indent$type$subject ($size bytes$deleted)\n";
-    $fh->print($text);
+    ref $fh eq 'GLOB' ? (print $fh $text) : $fh->print($text);
 
     my $body    = $self->body;
     my @parts
@@ -77,6 +77,5 @@ sub printStructure(;$$)
     $buffer;
 }
     
-#---------------------
 
 1;
