@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Convert::Html;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Convert';
 
-use strict;
-use warnings;
-
 use Carp;
 
 
@@ -35,6 +31,7 @@ sub init($)
 
 #------------------------------------------
 
+
 sub textToHtml(@)
 {   my $self  = shift;
 
@@ -46,6 +43,8 @@ sub textToHtml(@)
     wantarray ? @lines : join('', @lines);
 }
 
+#------------------------------------------
+
 
 sub fieldToHtml($;$)
 {   my ($self, $field, $subject) = @_;
@@ -53,6 +52,8 @@ sub fieldToHtml($;$)
     .': </strong>' . $self->fieldContentsToHtml($field,$subject);
 }
 
+#------------------------------------------
+
 
 sub headToHtmlTable($;$)
 {   my ($self, $head) = (shift, shift);
@@ -64,7 +65,7 @@ sub headToHtmlTable($;$)
 
         use Mail::Message::Construct;
         $subject = Mail::Message::Construct->replySubject($s)
-            if defined $s;
+            if defined $subject;
     }
 
     my @lines = "<table $tp>\n";
@@ -79,11 +80,13 @@ sub headToHtmlTable($;$)
     wantarray ? @lines : join('',@lines);
 }
 
+#------------------------------------------
+
 
 sub headToHtmlHead($@)
 {   my ($self, $head) = (shift,shift);
     my %meta;
-    while(@_) { my $k = shift; $meta{lc $k} = shift }
+    while(@_) {my $k = shift; $meta{lc $k} = shift }
 
     my $title = delete $meta{title} || $head->get('subject') || '<no subject>';
 
@@ -99,7 +102,8 @@ sub headToHtmlHead($@)
         $author  = @addr ? $addr[0]->format : undef;
     }
 
-    push @lines, '<meta name="Author" content="' . $self->textToHtml($author) . "\"$self->{MMCH_tail}\n"
+    push @lines, '<meta name="Author" content="'
+               . $self->textToHtml($author) . "\"$self->{MMCH_tail}\n"
         if defined $author;
 
     foreach my $f (map {lc} keys %meta)
@@ -120,6 +124,8 @@ sub headToHtmlHead($@)
     wantarray ? @lines : join('',@lines);
 }
     
+#------------------------------------------
+
 
 my $atom          = qr/[^()<>@,;:\\".\[\]\s[:cntrl:]]+/;
 my $email_address = qr/(($atom(?:\.$atom)*)\@($atom(?:\.$atom)+))/o;
@@ -136,4 +142,6 @@ sub fieldContentsToHtml($;$)
     $body . ($comment ? '; '.$self->textToHtml($comment) : '');
 }
 
+#------------------------------------------
+
 1;
