@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Convert::HtmlFormatText;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Convert';
 
-use strict;
-use warnings;
-
 use Mail::Message::Body::String;
 
 use HTML::TreeBuilder;
@@ -27,9 +23,9 @@ sub init($)
     $self->SUPER::init($args);
 
     $self->{MMCH_formatter} = HTML::FormatText->new
-      ( leftmargin  => $args->{leftmargin}  //  3,
-      , rightmargin => $args->{rightmargin} // 72,
-      );
+     ( leftmargin  => (defined $args->{leftmargin}  ? $args->{leftmargin}  : 3)
+     , rightmargin => (defined $args->{rightmargin} ? $args->{rightmargin} : 72)
+     );
       
     $self;
 }
