@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Field;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Reporter';
 
-use strict;
-use warnings;
-
 use Carp;
 use Mail::Address;
 use Date::Format 'strftime';
@@ -25,7 +21,7 @@ my $default_wrap_length = 78;
 
 
 use overload
-   qq("")  => sub { $_[0]->unfoldedBody }
+    qq("") => sub { $_[0]->unfoldedBody }
  , '0+'    => sub { $_[0]->toInt || 0 }
  , bool    => sub {1}
  , cmp     => sub { $_[0]->unfoldedBody cmp "$_[1]" }
@@ -137,10 +133,10 @@ sub folded { shift->notImplemented }
 sub body()
 {   my $self = shift;
     my $body = $self->unfoldedBody;
-    $self->isStructured or return $body;
+    return $body unless $self->isStructured;
 
-    my ($first) = $body =~ m/^((?:"[^"]*"|'[^']*'|[^;])*)/;
-	$first =~ s/\s+$//r;
+    $body =~ s/\s*\;.*//s;
+    $body;
 }
 
 
@@ -174,14 +170,21 @@ sub stripCFWS($)
     }
 
     # beautify and unfold at the same time
-    $r =~ s/\s+/ /grs =~ s/\s+$//r =~ s/^\s+//r;
+    for($r)
+    {  s/\s+/ /gs;
+       s/\s+$//;
+       s/^\s+//;
+    }
+
+    $r;
 }
 
 #------------------------------------------
 
+
 sub comment(;$)
 {   my $self = shift;
-    $self->isStructured or return undef;
+    return undef unless $self->isStructured;
 
     my $body = $self->unfoldedBody;
 
@@ -201,18 +204,22 @@ sub content() { shift->unfoldedBody }  # Compatibility
 
 sub attribute($;$)
 {   my ($self, $attr) = (shift, shift);
+    my $body  = $self->unfoldedBody;
 
-	# Although each attribute can appear only once, some (intentionally)
-	# broken messages do repeat them.  See github issue 20.  Apple Mail and
-	# Outlook will take the last of the repeated in such case, so we do that
-	# as well.
-	my %attrs = $self->attributes;
-	@_ or return $attrs{$attr};
+    unless(@_)
+    {   # only get a value
+        if($body =~ m/\b$attr\s*\=\s*
+                      ( "( (?> [^\\"]+|\\. )* )"
+                      | ([^";\s]*)
+                      )/xi)
+        {   (my $val = $+) =~ s/\\(.)/$1/g;
+            return $val;
+        }
+        return undef;
+    }
 
     # set the value
     my $value = shift;
-    my $body  = $self->unfoldedBody;
-
     unless(defined $value)  # remove attribute
     {   for($body)
         {      s/\b$attr\s*=\s*"(?>[^\\"]|\\.)*"//i
@@ -222,7 +229,7 @@ sub attribute($;$)
         return undef;
     }
 
-    my $quoted = $value =~ s/(["\\])/\\$1/gr;
+    (my $quoted = $value) =~ s/(["\\])/\\$1/g;
 
     for($body)
     {       s/\b$attr\s*=\s*"(?>[^\\"]|\\.){0,1000}"/$attr="$quoted"/i
@@ -234,6 +241,8 @@ sub attribute($;$)
     $value;
 }
 
+#------------------------------------------
+
 
 sub attributes()
 {   my $self  = shift;
@@ -252,16 +261,20 @@ sub attributes()
     @attrs;
 }
 
+#------------------------------------------
+
 
 sub toInt()
 {   my $self = shift;
-    $self->body =~ m/^\s*(\d+)\s*$/
-        and return $1;
+    return $1 if $self->body =~ m/^\s*(\d+)\s*$/;
 
     $self->log(WARNING => "Field content is not numerical: ". $self->toString);
-    undef;
+
+    return undef;
 }
 
+#------------------------------------------
+
 
 my @weekday = qw/Sun Mon Tue Wed Thu Fri Sat Sun/;
 my @month   = qw/Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec/;
@@ -273,23 +286,30 @@ sub toDate(@)
     my $time   = strftime $format, @time;
 
     # for C libs which do not (GNU compliantly) support %z
-    $time =~ s/ (\%z|[A-Za-z ]+)$/_tz_offset($1)/re;
+    $time =~ s/ (\%z|[A-Za-z ]+)$/_tz_offset($1)/e;
+
+    $time; 
 }
 
 sub _tz_offset($)
 {  my $zone = shift;
    require Time::Zone;
 
-   my $diff = $zone eq '%z' ? Time::Zone::tz_local_offset() : Time::Zone::tz_offset($zone);
+   my $diff = $zone eq '%z' ? Time::Zone::tz_local_offset()
+           :                  Time::Zone::tz_offset($zone);
    my $minutes = int((abs($diff)+0.01) / 60);     # float rounding errors
    my $hours   = int(($minutes+0.01) / 60);
    $minutes   -= $hours * 60;
-   sprintf +($diff < 0 ? " -%02d%02d" : " +%02d%02d"), $hours, $minutes;
+   sprintf( ($diff < 0 ? " -%02d%02d" : " +%02d%02d"), $hours, $minutes);
 }
 
+#------------------------------------------
+
 
 sub addresses() { Mail::Address->parse(shift->unfoldedBody) }
 
+#------------------------------------------
+
 
 sub study()
 {   my $self = shift;
@@ -313,19 +333,25 @@ sub dateToTimestamp($)
 
 #------------------------------------------
 
+
+#=notice Empty field: $name
+#Empty fields are not allowed, however sometimes found in messages constructed
+#by broken applications.  You probably want to ignore this message unless you
+#wrote this broken application yourself.
+
 sub consume($;$)
 {   my $self = shift;
     my ($name, $body) = defined $_[1] ? @_ : split(/\s*\:\s*/, (shift), 2);
 
-    $name !~ m/[^\041-\071\073-\176]/
-        or Mail::Reporter->log(WARNING => "Illegal character in field name $name");
+    Mail::Reporter->log(WARNING => "Illegal character in field name $name")
+       if $name =~ m/[^\041-\071\073-\176]/;
 
     #
     # Compose the body.
     #
 
     if(ref $body)                 # Objects or array
-    {   my $flat = $self->stringifyData($body) // return ();
+    {   my $flat = $self->stringifyData($body) or return ();
         $body = $self->fold($name, $flat);
     }
     elsif($body !~ s/\n+$/\n/g)   # Added by user...
@@ -335,93 +361,97 @@ sub consume($;$)
     {   # correct erroneous wrap-seperators (dos files under UNIX)
         $body =~ s/[\012\015]+/\n/g;
         $body =~ s/^[ \t]*/ /;  # start with one blank, folding kept unchanged
+
+        $self->log(NOTICE => "Empty field: $name")
+           if $body eq " \n";
     }
 
     ($name, $body);
 }
 
+#------------------------------------------
+
 
 sub stringifyData($)
 {  my ($self, $arg) = (shift, shift);
    my @addr;
    foreach my $obj (ref $arg eq 'ARRAY' ? @$arg : ($arg))
-   {   defined $obj or next;
+   {  next unless defined $obj;
 
-       if(!ref $obj)                  { push @addr, $obj; next }
-       if($obj->isa('Mail::Address')) { push @addr, $obj->format; next }
+      if(!ref $obj)                  { push @addr, $obj; next }
+      if($obj->isa('Mail::Address')) { push @addr, $obj->format; next }
 
-       if($obj->isa('Mail::Identity') || $obj->isa('User::Identity'))
-       {   require Mail::Message::Field::Address;
-           push @addr, Mail::Message::Field::Address->coerce($obj)->string;
-       }
-       elsif($obj->isa('User::Identity::Collection::Emails'))
-       {   my @roles = $obj->roles or next;
-           require Mail::Message::Field::AddrGroup;
-           my $group = Mail::Message::Field::AddrGroup->coerce($obj);
-           push @addr, $group->string if $group;
-       }
-       elsif($obj->isa('Mail::Message::Field'))
-       {   my $folded = join ' ', $obj->foldedBody;
-           push @addr, $folded =~ s/^ //r =~ s/\n\z//r;
-       }
-       else
-       {   push @addr, "$obj";    # any other object is stringified
-       }
+      if($obj->isa('Mail::Identity') || $obj->isa('User::Identity'))
+      {   require Mail::Message::Field::Address;
+          push @addr, Mail::Message::Field::Address->coerce($obj)->string;
+      }
+      elsif($obj->isa('User::Identity::Collection::Emails'))
+      {   my @roles = $obj->roles or next;
+          require Mail::Message::Field::AddrGroup;
+          my $group = Mail::Message::Field::AddrGroup->coerce($obj);
+          push @addr, $group->string if $group;
+      }
+      else
+      {    # any other object is stringified
+           push @addr, "$obj";
+      }
    }
 
    @addr ? join(', ',@addr) : undef;
 }
 
+#------------------------------------------
+
 
 sub setWrapLength(;$)
 {   my $self = shift;
 
-    $self->foldedBody(scalar $self->fold($self->Name, $self->unfoldedBody, $_[0]))
+    $self->foldedBody(scalar $self->fold($self->Name, $self->unfoldedBody, @_))
         if @_;
 
     $self;
 }
 
+#------------------------------------------
+
 
 sub defaultWrapLength(;$)
 {   my $self = shift;
     @_ ? ($default_wrap_length = shift) : $default_wrap_length;
 }
 
+#------------------------------------------
+
 
 sub fold($$;$)
 {   my $thing = shift;
     my $name  = shift;
     my $line  = shift;
     my $wrap  = shift || $default_wrap_length;
-    $line   //= '';
+    defined $line or $line = '';
 
-    $line    =~ s/\n(\s)/$1/gms;            # Remove accidental folding
-    CORE::length($line) or return " \n";    # empty field
-
-    my $lname = CORE::length($name);
-    $lname <= $wrap -5  # Cannot find a real limit in the spec
-        or $thing->log(ERROR => "Field name too long (max ".($wrap-5)."), in '$name'");
+    $line    =~ s/\n\s/ /gms;            # Remove accidental folding
+    return " \n" unless CORE::length($line);  # empty field
 
     my @folded;
     while(1)
-    {   my $max = $wrap - (@folded ? 1 : $lname + 2);
-        my $min = $max >> 2;
-        last if CORE::length($line) < $max;
+    {  my $max = $wrap - (@folded ? 1 : CORE::length($name) + 2);
+       my $min = $max >> 2;
+       last if CORE::length($line) < $max;
 
-           $line =~ s/^ ( .{$min,$max}   # $max to 30 chars
-                         [;,]            # followed at a ; or ,
-                        )[ \t]           # and then a WSP
-                     //x
-        || $line =~ s/^ ( .{$min,$max} ) # $max to 30 chars
-                        [ \t]            # followed by a WSP
-                     //x
-        || $line =~ s/^ ( .{$max,}? )    # longer, but minimal chars
-                        [ \t]            # followed by a WSP
-                     //x
-        || $line =~ s/^ (.*) //x;        # everything
+          $line =~ s/^ ( .{$min,$max}   # $max to 30 chars
+                        [;,]            # followed at a ; or ,
+                       )[ \t]           # and then a WSP
+                    //x
+       || $line =~ s/^ ( .{$min,$max} ) # $max to 30 chars
+                       [ \t]            # followed by a WSP
+                    //x
+       || $line =~ s/^ ( .{$max,}? )    # longer, but minimal chars
+                       [ \t]            # followed by a WSP
+                    //x
+       || $line =~ s/^ (.*) //x;        # everything
 
-        push @folded, " $1\n";
+       push @folded, " $1\n";
     }
 
     push @folded, " $line\n" if CORE::length($line);
@@ -432,14 +462,13 @@ sub fold($$;$)
 sub unfold($)
 {   my $string = $_[1];
     for($string)
-    {   s/\r?\n(\s)/$1/gs;  # remove FWS
-        s/\r?\n/ /gs;
-        s/^\s+//;
-        s/\s+$//;
+    {   s/\r?\n//gm;
+        s/^ +//;
     }
     $string;
 }
 
 #------------------------------------------
 
+
 1;
