@@ -1,31 +1,26 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
-
-package Mail::Message::Field::Address;
-use vars '$VERSION';
-$VERSION = '3.018_001';
-
-use base 'Mail::Identity';
-
 use strict;
 use warnings;
 
+package Mail::Message::Field::Address;
+use vars '$VERSION';
+$VERSION = '3.001';
+
+use base 'Mail::Identity';
+
 use Mail::Message::Field::Addresses;
 use Mail::Message::Field::Full;
-
 my $format = 'Mail::Message::Field::Full';
 
 
 use overload
-    '""' => 'string'
-  , bool => sub {1}
-  , cmp  => sub { lc($_[0]->address) cmp lc($_[1]) }
-  ;
+      '""' => 'string'
+    , bool => sub {1}
+    , cmp  => sub { lc($_[0]->address) eq lc($_[1]) }
+    ;
 
 #------------------------------------------
 
@@ -55,7 +50,7 @@ sub init($)
 
 sub parse($)
 {   my $self   = shift;
-    my $parsed = Mail::Message::Field::Addresses->new(To => shift);
+    my $parsed = Mail::Message::Field::Addresses->new('To' => shift);
     defined $parsed ? ($parsed->addresses)[0] : ();
 }
 
@@ -73,8 +68,8 @@ sub string()
        # language => $self->language
 
     my @parts;
-    my $phrase  = $self->phrase;
-    push @parts, $format->createPhrase($phrase, @opts) if defined $phrase;
+    my $name    = $self->phrase;
+    push @parts, $format->createPhrase($name, @opts) if defined $name;
 
     my $address = $self->address;
     push @parts, @parts ? '<'.$address.'>' : $address;
