@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Field::Addresses;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Field::Structured';
 
-use strict;
-use warnings;
-
 use Mail::Message::Field::AddrGroup;
 use Mail::Message::Field::Address;
 use List::Util 'first';
@@ -37,7 +33,7 @@ sub init($)
 
     $self->{MMFF_groups}   = [];
 
-    my $def = lc $args->{name} =~ s/^resent\-//r;
+    ( my $def = lc $args->{name} ) =~ s/^resent\-//;
     $self->{MMFF_defaults} = $accepted{$def} || $address_list;
 
     my ($body, @body);
@@ -47,7 +43,7 @@ sub init($)
     }
 
     if(@body > 1 || ref $body[0])
-    {   $self->addAddress($_) for @body;
+    {   $self->addAddress($_) foreach @body;
         delete $args->{body};
     }
 
@@ -75,7 +71,9 @@ sub addAddress(@)
 
 sub addGroup(@)
 {   my $self  = shift;
-    my $group = @_ == 1 ? shift : Mail::Message::Field::AddrGroup->new(@_);
+    my $group = @_ == 1 ? shift
+              : Mail::Message::Field::AddrGroup->new(@_);
+
     push @{$self->{MMFF_groups}}, $group;
     $group;
 }
@@ -111,13 +109,11 @@ sub parse($)
     my ($group, $email) = ('', undef);
     $string =~ s/\s+/ /gs;
 
-  ADDRESS:
     while(1)
     {   (my $comment, $string) = $self->consumeComment($string);
-        my $start_length = length $string;
 
-        if($string =~ s/^\s*\;//s ) { $group = ''; next ADDRESS }  # end group
-        if($string =~ s/^\s*\,//s ) { next ADDRESS}               # end address
+        if($string =~ s/^\s*\;//s ) { $group = ''; next }  # end group
+        if($string =~ s/^\s*\,//s ) { next }               # end address
 
         (my $email, $string) = $self->consumeAddress($string);
         if(defined $email)
@@ -128,33 +124,25 @@ sub parse($)
         else
         {   # Pattern not plain address
             my $real_phrase = $string =~ m/^\s*\"/;
-            my @words;
+            (my $phrase, $string) = $self->consumePhrase($string);
 
-            # In rfc2822 obs-phrase, we can have more than one word with
-            # comments inbetween.
-         WORD:
-            while(1)
-            {   (my $word, $string) = $self->consumePhrase($string);
-                defined $word or last;
-
-                push @words, $word if length $word;
-                ($comment, $string) = $self->consumeComment($string);
+            if(defined $phrase)
+            {   ($comment, $string) = $self->consumeComment($string);
 
                 if($string =~ s/^\s*\://s )
-                {   $group = $word;
+                {   $group = $phrase;
                     # even empty groups must appear
-                    $self->addGroup(name => $group) unless $self->group($group);
-                    next ADDRESS;
+                    $self->addGroup(name=>$group) unless $self->group($group);
+                    next;
                 }
             }
-            my $phrase = @words ? join ' ', @words : undef;
 
             my $angle;
             if($string =~ s/^\s*\<([^>]*)\>//s) { $angle = $1 }
             elsif($real_phrase)
             {   $self->log(ERROR => "Ignore unrelated phrase `$1'")
                     if $string =~ s/^\s*\"(.*?)\r?\n//;
-                next ADDRESS;
+                next;
             }
             elsif(defined $phrase)
             {   ($angle = $phrase) =~ s/\s+/./g;
@@ -173,12 +161,10 @@ sub parse($)
 
         $self->addAddress($email, group => $group) if defined $email;
         return 1 if $string =~ m/^\s*$/s;
-
-        # Do not get stuck on illegal characters
-        last if $start_length == length $string;
    }
 
-   $self->log(WARNING => 'Illegal part in address field '.$self->Name. ": $string\n");
+   $self->log(WARNING => 'Illegal part in address field '.$self->Name.
+        ": $string\n");
 
    0;
 }
@@ -190,37 +176,30 @@ sub produceBody()
    @groups > 1 or return $groups[0]->string;
 
    my $plain
-     = $groups[0]->name eq '' && $groups[0]->addresses
-     ? (shift @groups)->string.','
-     : '';
+    = $groups[0]->name eq '' && $groups[0]->addresses
+    ? (shift @groups)->string.','
+    : '';
 
-   join ' ', $plain, (map $_->string, @groups);
+   join ' ', $plain, map({$_->string} @groups);
 }
 
 
 sub consumeAddress($@)
 {   my ($self, $string, @options) = @_;
 
-    my ($local, $shorter, $loccomment);
-    if($string =~ s/^\s*"((?:\\.|[^"])*)"\s*\@/@/)
-    {   # local part is quoted-string rfc2822
-        ($local, $shorter) = ($1, $string);
-        $local =~ s/\\"/"/g;
-    }
-    else
-    {   ($local, $shorter, $loccomment) = $self->consumeDotAtom($string);
-        $local =~ s/\s//g if defined $local;
-    }
+    my ($local, $shorter, $loccomment) = $self->consumeDotAtom($string);
+    $local =~ s/\s//g if defined $local;
 
-    defined $local && $shorter =~ s/^\s*\@//
-        or return (undef, $string);
+    return (undef, $string)
+        unless defined $local && $shorter =~ s/^\s*\@//;
   
     (my $domain, $shorter, my $domcomment) = $self->consumeDomain($shorter);
-    defined $domain
-        or return (undef, $string);
+    return (undef, $string) unless defined $domain;
 
     # loccomment and domcomment ignored
-    my $email   = Mail::Message::Field::Address->new(username => $local, domain => $domain, @options);
+    my $email   = Mail::Message::Field::Address
+        ->new(username => $local, domain => $domain, @options);
+
     ($email, $shorter);
 }
 
@@ -238,4 +217,5 @@ sub consumeDomain($)
 
 #------------------------------------------
 
+
 1;
