@@ -1,21 +1,18 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
-
-package Mail::Message::Field::Attribute;
-use vars '$VERSION';
-$VERSION = '3.018_001';
-
-use base 'Mail::Reporter';
-
 use strict;
 use warnings;
 
+package Mail::Message::Field::Attribute;
+use vars '$VERSION';
+$VERSION = '3.001';
+
+use base 'Mail::Reporter';
+use 5.007003;
 use Encode ();
+
 use Carp;
 
 
@@ -52,8 +49,8 @@ sub init($$)
     $self->{MMFF_charset}  = $args->{charset}  if defined $args->{charset};
     $self->{MMFF_language} = $args->{language} if defined $args->{language};
 
-    $self->value(defined $value ? "$value" : '');  # enforce stringification
-    $self->addComponent($attr) if $attr ne $name;
+    $self->value(defined $value ? $value : '');
+    $self->addComponent($attr) unless $attr eq $name;
 
     $self;
 }
@@ -76,7 +73,6 @@ sub value(;$)
 
 sub addComponent($)
 {   my ($self, $component) = @_;
-    defined $component or return;
     delete $self->{MMFF_value};
 
     my ($name, $value) = split /\=/, $component, 2;
@@ -102,11 +98,16 @@ sub language() { shift->{MMFF_language} }
 sub string()
 {   my $self = shift;
     my $cont = $self->{MMFF_cont} || $self->encode;
-    wantarray? @$cont : (join '; ', '', @$cont);
+    return @$cont if wantarray;
+    return [] unless @$cont;
+
+    local $" = "; ";
+    "; @$cont";
 }
 
 #------------------------------------------
 
+
 sub encode()
 {   my $self  = shift;
     my $value = $self->{MMFF_value};
@@ -199,12 +200,15 @@ sub decode()
 
 #------------------------------------------
 
+
 sub mergeComponent($)
 {   my ($self, $comp) = @_;
     my $cont  = $self->{MMFF_cont}
         or croak "ERROR: Too late to merge: value already changed.";
 
-    $self->addComponent($_) for @{$comp->{MMFF_cont}};
+    defined $_ && $self->addComponent($_)
+        foreach @{$comp->{MMFF_cont}};
+
     $self;
 }
 
