@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use warnings;
+use strict;
 
 package Mail::Message::Field::Date;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Field::Structured';
 
-use warnings;
-use strict;
-
 use POSIX qw/mktime tzset/;
 
 
@@ -33,7 +29,7 @@ sub parse($)
            (?: ($dayname) \s* \, \s* )?
            ( 0?[1-9] | [12][0-9] | 3[01] ) \s*    # day
            \s+ ( [A-Z][a-z][a-z]|[0-9][0-9] ) \s+ # month
-           ( (?: 19 | 20 | ) [0-9][0-9] ) \s+     # year
+           ( 19[0-9][0-9] | 2[0-9]{3} ) \s+       # year
                   ( [0-1]?[0-9] | 2[0-3] ) \s*    # hour
                [:.] ( [0-5][0-9] ) \s*            # minute
            (?: [:.] ( [0-5][0-9] ) )? \s+         # second
@@ -63,6 +59,7 @@ sub date() { shift->{MMFD_date} }
 
 #------------------------------------------
 
+
 sub addAttribute($;@)
 {   my $self = shift;
     $self->log(ERROR => 'No attributes for date fields.');
@@ -90,4 +87,5 @@ sub time()
 
 #------------------------------------------
 
+
 1;
