@@ -1,21 +1,15 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
-
-package Mail::Message::Field::Fast;
-use vars '$VERSION';
-$VERSION = '3.018_001';
-
-use base 'Mail::Message::Field';
-
 use strict;
 use warnings;
 
-use Scalar::Util  qw/blessed/;
+package Mail::Message::Field::Fast;
+use vars '$VERSION';
+$VERSION = '3.001';
+
+use base 'Mail::Message::Field';
 
 
 #------------------------------------------
@@ -84,7 +78,8 @@ sub foldedBody($)
 sub print(;$)
 {   my $self = shift;
     my $fh   = shift || select;
-    $fh->print($self->[0].':'.$self->[1]);
+    if(ref $fh eq 'GLOB') { print $fh $self->[0].':'.$self->[1]   }
+    else                  { $fh->print($self->[0].':'.$self->[1]) }
     $self;
 }
 
