@@ -1,37 +1,29 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Field::Full;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Field';
 
-use strict;
-use warnings;
 use utf8;
-
 use Encode ();
 use MIME::QuotedPrint ();
 use Storable 'dclone';
 
-use Mail::Message::Field::Addresses;
-use Mail::Message::Field::AuthResults;
-#use Mail::Message::Field::AuthRecChain;
-use Mail::Message::Field::Date;
-use Mail::Message::Field::DKIM;
 use Mail::Message::Field::Structured;
 use Mail::Message::Field::Unstructured;
+use Mail::Message::Field::Addresses;
 use Mail::Message::Field::URIs;
+use Mail::Message::Field::Date;
 
-my $atext      = q[a-zA-Z0-9!#\$%&'*+\-\/=?^_`{|}~];  # from RFC5322
-my $utf8_atext = q[\p{Alnum}!#\$%&'*+\-\/=?^_`{|}~];  # from RFC5335
-my $atext_ill  = q/\[\]/;     # illegal, but still used (esp spam)
+my $atext = q[a-zA-Z0-9!#\$%&'*+\-\/=?^_`{|}~];  # from RFC
+my $atext_ill = q/\[\]/;     # illegal, but still used (esp spam)
 
 
 use overload '""' => sub { shift->decodedBody };
@@ -55,12 +47,6 @@ BEGIN {
       for qw/content-disposition content-type content-id/;
    $implementation{$_} = 'Date'
       for qw/date resent-date/;
-   $implementation{$_} = 'AuthResults'
-      for qw/authentication-results/;
-   $implementation{$_} = 'DKIM'
-      for qw/dkim-signature/;
-#  $implementation{$_} = 'AuthRecChain'
-#     for qw/arc-authentication-results arc-message-signature arc-seal/;
 }
 
 sub new($;$$@)
@@ -122,7 +108,10 @@ sub unfoldedBody($;$)
          return $body;
     }
 
-    $self->foldedBody =~ s/\r?\n(\s)/$1/gr =~ s/\r?\n/ /gr =~  s/^\s+//r =~ s/\s+$//r;
+    $body = $self->foldedBody;
+    $body =~ s/^ //;
+    $body =~ s/\n//g;
+    $body;
 }
 
 sub foldedBody($)
@@ -185,13 +174,6 @@ sub createComment($@)
 sub createPhrase($)
 {   my $self = shift;
     local $_ = shift;
-
-    # I do not case whether it gets a but sloppy in the header string,
-    # as long as it is functionally correct: no folding inside phrase
-    # quotes.
-    return $_ = $self->encode($_, @_, force => 1)
-        if length $_ > 50;
-
     $_ =  $self->encode($_, @_)
         if @_;  # encoding required...
 
@@ -212,12 +194,11 @@ sub beautify() { shift }
 
 sub _mime_word($$) { "$_[0]$_[1]?=" }
 sub _encode_b($)   { MIME::Base64::encode_base64(shift, '')  }
-
-sub _encode_q($)   # RFC2047 sections 4.2 and 5
+sub _encode_q($)
 {   my $chunk = shift;
-    $chunk =~ s#([^a-zA-Z0-9!*+/_ -])#sprintf "=%02X", ord $1#ge;
-    $chunk =~ s#([_\?,"])#sprintf "=%02X", ord $1#ge;
-    $chunk =~ s/ /_/g;     # special case for =? ?= use
+    $chunk =~ s#([\x00-\x1F=\x7F-\xFF])#sprintf "=%02X", ord $1#ge;
+    $chunk =~ s#([_\?])#sprintf "=%02X", ord $1#ge;
+    $chunk =~ s/ /_/g;
     $chunk;
 }
 
@@ -230,9 +211,7 @@ sub encode($@)
     {   $self->log(WARNING => "Illegal character in charset '$charset'")
             if $charset =~ m/[\x00-\ ()<>@,;:"\/[\]?.=\\]/;
     }
-    else
-    {   $charset = $utf8 =~ /\P{ASCII}/ ? 'utf8' : 'us-ascii';
-    }
+    else { $charset = 'us-ascii' }
 
     if($lang = $args{language})
     {   $self->log(WARNING => "Illegal character in language '$lang'")
@@ -247,27 +226,22 @@ sub encode($@)
     }
     else { $encoding = 'q' }
 
-    my $name  = $args{name};
-    my $lname = defined $name ? length($name)+1 : 0;
-
     return $utf8
         if lc($encoding) eq 'q'
-        && length $utf8 < 70
-        && ($utf8 =~ m/\A[\p{IsASCII}]+\z/ms && !$args{force});
+        && $utf8 =~ m/\A[\p{IsASCII}]+\z/ms
+        && !$args{force};
 
     my $pre = '=?'. $charset. ($lang ? '*'.$lang : '') .'?'.$encoding.'?';
 
     my @result;
     if(lc($encoding) eq 'q')
-    {   my $chunk  = '';
-        my $llen = 73 - length($pre) - $lname;
-
+    {   my $llen = 73 - length $pre;
+        my $chunk  = '';
         while(length(my $chr = substr($utf8, 0, 1, '')))
         {   $chr  = _encode_q Encode::encode($charset, $chr, 0);
             if(bytes::length($chunk) + bytes::length($chr) > $llen)
             {   push @result, _mime_word($pre, $chunk);
                 $chunk = '';
-                $llen = 73 - length $pre;
             }
             $chunk .= $chr;
         }
@@ -275,14 +249,13 @@ sub encode($@)
             if length($chunk);
     }
     else
-    {    my $chunk  = '';
-         my $llen = int((73 - length($pre) - $lname) / 4) * 3;
+    {    my $llen = int((73 - length($pre)) / 4) * 3;
+         my $chunk  = '';
          while(length(my $chr = substr($utf8, 0, 1, '')))
          {   my $chr = Encode::encode($charset, $chr, 0);
              if(bytes::length($chunk) + bytes::length($chr) > $llen)
              {   push @result, _mime_word($pre, _encode_b($chunk));
                  $chunk = '';
-                 $llen  = int((73 - length $pre) / 4) * 3;
              }
              $chunk .= $chr;
         }
@@ -305,8 +278,9 @@ sub _decoder($$$)
     {   $decoded = $encoded;
     }
     elsif(lc($encoding) eq 'q')
-    {   # Quoted-printable encoded specific to mime-fields
-        $decoded = MIME::QuotedPrint::decode_qp($encoded =~ s/_/ /gr);
+    {   # Quoted-printable encoded
+        $encoded =~ s/_/ /g;   # specific to mime-fields
+        $decoded = MIME::QuotedPrint::decode_qp($encoded);
     }
     elsif(lc($encoding) eq 'b')
     {   # Base64 encoded
@@ -328,7 +302,7 @@ sub decode($@)
 
     my %args    = @_;
 
-    my $is_text = exists $args{is_text} ? $args{is_text} : 1;
+    my $is_text = defined $args{is_text} ? $args{is_text} : 1;
     my @decoded = shift @encoded;
 
     while(@encoded)
@@ -347,6 +321,7 @@ sub decode($@)
 
 #------------------------------------------
 
+
 sub parse($) { shift }
 
 
@@ -357,42 +332,36 @@ sub consumePhrase($)
     if($string =~ s/^\s*\" ((?:[^"\r\n\\]*|\\.)*) (?:\"|\s*$)//x )
     {   ($phrase = $1) =~ s/\\\"/"/g;
     }
-    elsif($string =~ s/^\s*((?:\=\?.*?\?\=|[${utf8_atext}${atext_ill}\ \t.])+)//o )
+    elsif($string =~ s/^\s*([${atext}${atext_ill}\ \t.]+)//o )
     {   ($phrase = $1) =~ s/\s+$//;
         CORE::length($phrase) or undef $phrase;
     }
         
-    defined $phrase ? ($thing->decode($phrase), $string) : (undef, $string);
+      defined $phrase
+    ? ($thing->decode($phrase), $string)
+    : (undef, $string);
 }
 
 
 sub consumeComment($)
 {   my ($thing, $string) = @_;
-    # Backslashes are officially not permitted in comments, but not everyone
-    # knows that.  Nested parens are supported.
 
-    $string =~ s/^\s* \( ((?:\\.|[^)])*) (?:\)|$) //x
-        or return (undef, $string);    # allow unterminated comments
+    return (undef, $string)
+        unless $string =~ s/^\s*\(((?:[^)\\]+|\\.)*)\)//;
 
     my $comment = $1;
-
-    # Continue consuming characters until we have balanced parens, for
-    # nested comments which are permitted.
     while(1)
     {   (my $count = $comment) =~ s/\\./xx/g;
-        last if +( $count =~ tr/(// ) == ( $count =~ tr/)// );
 
-        last if $string !~ s/^((?:\\.|[^)])*) \)//x;  # cannot satisfy
+        last if $count =~ tr/(//  ==  $count =~ tr/)//;
+
+        return (undef, $_[1])
+            unless $string =~ s/^((?:[^)\\]+|\\.)*)\)//;
 
         $comment .= ')'.$1;
     }
 
-    for($comment)
-    {   s/^\s+//;
-        s/\s+$//;
-        s/\\ ( [()] )/$1/gx; # Remove backslashes before nested comment.
-    }
-
+    $comment =~ s/\\([()])/$1/g;
     ($comment, $string);
 }
 
@@ -405,8 +374,7 @@ sub consumeDotAtom($)
     {   (my $c, $string) = $self->consumeComment($string);
         if(defined $c) { $comment .= $c; next }
 
-        $string =~ s/^\s*([$atext]+(?:\.[$atext]+)*)//o
-            or last;
+        last unless $string =~ s/^\s*([$atext]+(?:\.[$atext]+)*)//o;
 
         $atom .= $1;
     }
@@ -420,4 +388,5 @@ sub produceBody() { $_[0]->{MMFF_body} }
 #------------------------------------------
 
 
+
 1;
