@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Field::Structured;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Field::Full';
 
-use strict;
-use warnings;
-
 use Mail::Message::Field::Attribute;
 use Storable 'dclone';
 
@@ -54,7 +50,7 @@ sub attribute($;$)
     }
 
     delete $self->{MMFF_body};
-    $self->{MMFS_attrs}{lc $name} = $attr;
+    $self->{MMFS_attrs}{$name} = $attr;
 }
 
 
@@ -62,21 +58,14 @@ sub attributes() { values %{shift->{MMFS_attrs}} }
 sub beautify() { delete shift->{MMFF_body} }
 
 
-sub attrPairs() { map +($_->name, $_->value), shift->attributes }
+sub attrPairs() { map { $_->name, $_->value } shift->attributes }
 
 #-------------------------
 
 
 sub parse($)
 {   my ($self, $string) = @_;
-
-    for($string)
-    {   # remove FWS, even within quoted strings
-        s/\r?\n(\s)/$1/gs;
-        s/\r?\n/ /gs;
-	    s/\s+$//;
-    }
-
+    chomp $string;
     my $datum = '';
     while(length $string && substr($string, 0, 1) ne ';')
     {   (undef, $string)  = $self->consumeComment($string);
@@ -130,8 +119,9 @@ sub produceBody()
     my $attrs = $self->{MMFS_attrs};
     my $datum = $self->{MMFS_datum};
 
-    join '; ', ($datum // '')
-       , map $_->string, @{$attrs}{sort keys %$attrs};
+    join '; '
+       , (defined $datum ? $datum : '')
+       , map {$_->string} @{$attrs}{sort keys %$attrs};
 }
 
 
