@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use warnings;
+use strict;
 
 package Mail::Message::Field::URIs;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Field::Structured';
 
-use warnings;
-use strict;
-
 use URI;
 
 
@@ -61,10 +57,11 @@ sub addURI(@)
 {   my $self  = shift;
     my $uri   = ref $_[0] ? shift : URI->new(@_);
     push @{$self->{MMFU_uris}}, $uri->canonical if defined $uri;
-    delete $self->{MMFF_body};
     $uri;
 }
 
+#------------------------------------------
+
 
 sub URIs() { @{shift->{MMFU_uris}} }
 
