@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Head;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Reporter';
 
-use strict;
-use warnings;
-
 use Mail::Message::Head::Complete;
 use Mail::Message::Field::Fast;
 
@@ -22,9 +18,8 @@ use Carp;
 use Scalar::Util 'weaken';
 
 
-use overload
-    qq("") => 'string_unless_carp',
-    bool   => 'isEmpty';
+use overload qq("") => 'string_unless_carp'
+           , bool   => 'isEmpty';
 
 # To satisfy overload in static resolving.
 sub toString() { shift->load->toString }
@@ -34,17 +29,18 @@ sub string_unless_carp()
 {   my $self = shift;
     return $self->toString unless (caller)[0] eq 'Carp';
 
-    my $class = ref $self =~ s/^Mail::Message/MM/r;
+    (my $class = ref $self) =~ s/^Mail::Message/MM/;
     "$class object";
 }
 
 #------------------------------------------
 
+
 sub new(@)
 {   my $class = shift;
 
     return Mail::Message::Head::Complete->new(@_)
-        if $class eq __PACKAGE__;
+       if $class eq __PACKAGE__;
 
     $class->SUPER::new(@_);
 }
@@ -109,6 +105,7 @@ sub knownNames() { keys %{shift->{MMH_fields}} }
 
 #------------------------------------------
 
+
 sub get($;$)
 {   my $known = shift->{MMH_fields};
     my $value = $known->{lc(shift)};
@@ -138,8 +135,8 @@ sub setField($$) {shift->add(@_)} # compatibility
 
 sub study($;$)
 {   my $self = shift;
-    return map $_->study, $self->get(@_)
-        if wantarray;
+    return map {$_->study} $self->get(@_)
+       if wantarray;
 
     my $got  = $self->get(@_);
     defined $got ? $got->study : undef;
