@@ -1,24 +1,20 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
+use warnings;
 
 package Mail::Message::Head::Complete;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Head';
 
-use strict;
-use warnings;
-
 use Mail::Box::Parser;
 use Mail::Message::Head::Partial;
 
-use Scalar::Util  qw/weaken blessed/;
+use Scalar::Util  qw/weaken/;
 use List::Util    qw/sum/;
 use Sys::Hostname qw/hostname/;
 
@@ -84,7 +80,7 @@ sub add(@)
     # Create object for this field.
 
     my $field
-      = @_==1 && blessed $_[0] ? shift     # A fully qualified field is added.
+      = @_==1 && ref $_[0] ? shift     # A fully qualified field is added.
       : ($self->{MMH_field_type} || 'Mail::Message::Field::Fast')->new(@_);
 
     return if !defined $field;
@@ -127,9 +123,9 @@ sub names() {shift->knownNames}
 sub grepNames(@)
 {   my $self = shift;
     my @take;
-    push @take, (ref $_ eq 'ARRAY' ? @$_ : $_) for @_;
+    push @take, (ref $_ eq 'ARRAY' ? @$_ : $_) foreach @_;
 
-    @take or return $self->orderedFields;
+    return $self->orderedFields unless @take;
 
     my $take;
     if(@take==1 && ref $take[0] eq 'Regexp')
@@ -141,22 +137,22 @@ sub grepNames(@)
         $take    = qr/^(?:(?:@take))/i;
     }
 
-    grep { $_->name =~ $take } $self->orderedFields;
+    grep {$_->name =~ $take} $self->orderedFields;
 }
 
 
-my @skip_none = qw/content-transfer-encoding content-disposition content-description content-id/;
-my %skip_none = map +($_ => 1), @skip_none;
+my @skip_none = qw/content-transfer-encoding content-disposition
+                   content-description content-id/;
+
+my %skip_none = map { ($_ => 1) } @skip_none;
 
 sub set(@)
 {   my $self = shift;
-    @_!=1 || defined $_[0] or return;
-
     my $type = $self->{MMH_field_type} || 'Mail::Message::Field::Fast';
     $self->{MMH_modified}++;
 
     # Create object for this field.
-    my $field = @_==1 && blessed $_[0] ? shift->clone : $type->new(@_);
+    my $field = @_==1 && ref $_[0] ? shift->clone : $type->new(@_);
 
     my $name  = $field->name;         # is already lower-cased
     my $known = $self->{MMH_fields};
@@ -270,18 +266,28 @@ sub spamDetected()
 
 
 sub print(;$)
-{   my $self = shift;
-    my $fh   = shift || select;
-    $_->print($fh) for $self->orderedFields;
-    $fh->print("\n");
+{   my $self  = shift;
+    my $fh    = shift || select;
+
+    $_->print($fh)
+        foreach $self->orderedFields;
+
+    if(ref $fh eq 'GLOB') { print $fh "\n" }
+    else                  { $fh->print("\n") }
+
     $self;
 }
 
 
 sub printUndisclosed($)
 {   my ($self, $fh) = @_;
-    $_->print($fh) for grep $_->toDisclose, $self->orderedFields;
-    $fh->print("\n");
+
+    $_->print($fh)
+       foreach grep {$_->toDisclose} $self->orderedFields;
+
+    if(ref $fh eq 'GLOB') { print $fh "\n" }
+    else                  { $fh->print("\n") }
+
     $self;
 }
 
@@ -295,23 +301,24 @@ sub printSelected($@)
 
         my $found;
         foreach my $pattern (@_)
-        {   $found = ref $pattern ? ($Name =~ $pattern) : ($name eq lc $pattern);
+        {   $found = ref $pattern?($Name =~ $pattern):($name eq lc $pattern);
             last if $found;
         }
 
-        if(!$found) { ; }
-        else        { $fh->print("\n") }
+           if(!$found)           { ; }
+        elsif(ref $fh eq 'GLOB') { print $fh "\n" }
+        else                     { $fh->print("\n") }
     }
 
     $self;
 }
 
 
-sub toString() { shift->string }
+sub toString() {shift->string}
 sub string()
 {   my $self  = shift;
 
-    my @lines = map $_->string, $self->orderedFields;
+    my @lines = map {$_->string} $self->orderedFields;
     push @lines, "\n";
 
     wantarray ? @lines : join('', @lines);
