@@ -1,14 +1,11 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Head::FieldGroup;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Reporter';
 
@@ -33,10 +30,10 @@ sub init($$)
       = $args->{head} || Mail::Message::Head::Partial->new;
 
     $self->add($_)                            # add specified object fields
-        for @{$args->{fields}};
+        foreach @{$args->{fields}};
 
     $self->add($_, delete $args->{$_})        # add key-value paired fields
-        for grep m/^[A-Z]/, keys %$args;
+        foreach grep m/^[A-Z]/, keys %$args;
 
     $self->{MMHF_version}  = $args->{version}  if defined $args->{version};
     $self->{MMHF_software} = $args->{software} if defined $args->{software};
@@ -46,12 +43,18 @@ sub init($$)
     $self;
 }
 
+#------------------------------------------
+
 
 sub implementedTypes() { shift->notImplemented }
 
+#------------------------------------------
+
 
 sub from($) { shift->notImplemented }
 
+#------------------------------------------
+
 
 sub clone()
 {   my $self = shift;
@@ -62,8 +65,11 @@ sub clone()
 
 #------------------------------------------
 
+
 sub head() { shift->{MMHF_head} }
 
+#------------------------------------------
+
 
 sub attach($)
 {   my ($self, $head) = @_;
@@ -71,14 +77,18 @@ sub attach($)
     $self;
 }
 
+#------------------------------------------
+
 
 sub delete()
-{   my $self = shift;
-    my $head = $self->head;
-    $head->removeField($_) for $self->fields;
+{   my $self   = shift;
+    my $head   = $self->head;
+    $head->removeField($_) foreach $self->fields;
     $self;
 }
 
+#------------------------------------------
+
 
 sub add(@)
 {   my $self = shift;
@@ -87,6 +97,8 @@ sub add(@)
     $self;
 }
 
+#------------------------------------------
+
 
 sub fields()
 {   my $self = shift;
@@ -94,9 +106,13 @@ sub fields()
     map { $head->get($_) } $self->fieldNames;
 }
 
+#------------------------------------------
+
 
 sub fieldNames() { @{shift->{MMHF_fns}} }
 
+#------------------------------------------
+
 
 sub addFields(@)
 {   my $self = shift;
@@ -111,9 +127,13 @@ sub addFields(@)
 
 sub version() { shift->{MMHF_version} }
 
+#------------------------------------------
+
 
 sub software() { shift->{MMHF_software} }
 
+#------------------------------------------
+
 
 sub type() { shift->{MMHF_type} }
 
@@ -125,17 +145,22 @@ sub detected($$$)
     @$self{ qw/MMHF_type MMHF_software MMHF_version/ } = @_;
 }
 
+#------------------------------------------
+
 
 sub collectFields(;$) { shift->notImplemented }
 
 #------------------------------------------
 
+
 sub print(;$)
 {   my $self = shift;
     my $out  = shift || select;
-    $_->print($out) for $self->fields;
+    $_->print($out) foreach $self->fields;
 }
 
+#------------------------------------------
+
 
 sub details()
 {   my $self     = shift;
@@ -153,4 +178,6 @@ sub details()
     "$type $release, $fields fields";
 }
 
+#------------------------------------------
+
 1;
