@@ -1,14 +1,11 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Head::ListGroup;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Head::FieldGroup';
 
@@ -28,8 +25,9 @@ sub init($$)
     {   require Mail::Message::Field::Address;
         my $mi   = Mail::Message::Field::Address->coerce($address);
 
-        defined $mi
-            or $self->log(ERROR => "Cannot convert \"$address\" into an address object"), return;
+        $self->log(ERROR =>
+                "Cannot convert \"$address\" into an address object"), return
+            unless defined $mi;
 
         $address = $mi;
     }
@@ -48,7 +46,8 @@ sub from($)
 {   my ($class, $from) = @_;
     my $head = $from->isa('Mail::Message::Head') ? $from : $from->head;
     my $self = $class->new(head => $head);
-    $self->collectFields or return ();
+
+    return () unless $self->collectFields;
 
     my ($type, $software, $version, $field);
     if(my $communigate = $head->get('X-ListServer'))
@@ -71,7 +70,8 @@ sub from($)
     {   ($software, $version) = $listar =~ m/^(.*?)\s+(v[\w.]+)/;
         $type    = 'Listar';
     }
-    elsif(defined($field = $head->get('List-Software')) && $field =~ m/listbox/i)
+    elsif(defined($field = $head->get('List-Software'))
+          && $field =~ m/listbox/i)
     {   ($software, $version) = $field =~ m/^(\S*)\s*(v[\d.]+)\s*$/;
         $type    = 'Listbox';
     }
@@ -81,7 +81,8 @@ sub from($)
             m!\( (LISTSERV-TCP/IP) \s+ release \s+ (\S+) \)!xs;
         $type = 'Listserv';
     }
-    elsif(defined($field = $head->get('X-Mailing-List')) && $field =~ m[archive/latest])
+    elsif(defined($field = $head->get('X-Mailing-List'))
+          && $field =~ m[archive/latest])
     {   $type    = 'Smartlist' }
     elsif(defined($field = $head->get('Mailing-List')) && $field =~ m/yahoo/i )
     {   $type    = 'YahooGroups' }
@@ -91,13 +92,15 @@ sub from($)
     {   ($software, $version) = $fml =~ m/^\s*(\S+)\s*\[\S*\s*([^\]]*?)\s*\]/;
         $type    = 'FML';
     }
-    elsif(defined($field = $head->get('List-Subscribe') || $head->get('List-Unsubscribe')) && $field =~ m/sympa/i)
+    elsif(defined($field = $head->get('List-Subscribe')
+                        || $head->get('List-Unsubscribe'))
+          && $field =~ m/sympa/i)
     {   $type    = 'Sympa' }
     elsif(first { m/majordom/i } $head->get('Received'))
     {   # Majordomo is hard to recognize
         $type    = "Majordomo";
     }
-    elsif(defined($field = $head->get('List-ID')) && $field =~ m/listbox\.com/i)
+    elsif($field = $head->get('List-ID') && $field =~ m/listbox\.com/i)
     {   $type    = "Listbox" }
 
     $self->detected($type, $software, $version);
@@ -112,11 +115,13 @@ sub rfc()
    return $self->{MMHL_rfc} if defined $self->{MMHL_rfc};
 
    my $head = $self->head;
-       defined $head->get('List-Post') ? 'rfc2369'
-     : defined $head->get('List-Id')   ? 'rfc2919'
-     :                                    undef;
+     defined $head->get('List-Post') ? 'rfc2369'
+   : defined $head->get('List-Id')   ? 'rfc2919'
+   :                                    undef;
 }
 
+#------------------------------------------
+
 
 sub address()
 {   my $self = shift;
@@ -133,7 +138,8 @@ sub address()
     elsif($type eq 'Listserv')
     {   $address = $head->get('Sender') }
 
-    $address ||= $head->get('List-Post') || $head->get('Reply-To') || $head->get('Sender');
+    $address ||= $head->get('List-Post') || $head->get('Reply-To')
+             || $head->get('Sender');
     $address = $address->study if ref $address;
 
        if(!defined $address) { ; }
@@ -146,12 +152,15 @@ sub address()
         $address     = ($address->addresses)[0];
         my $username = defined $address ? $address->username : '';
         if($username =~ s/^owner-|-(owner|bounce|admin)$//i)
-        {   $address = Mail::Message::Field::Address->new(username => $username, domain => $address->domain);
+        {   $address = Mail::Message::Field::Address->new
+               (username => $username, domain => $address->domain);
         }
     }
     elsif($address->isa('Mail::Message::Field::URIs'))
     {   my $uri  = first { $_->scheme eq 'mailto' } $address->URIs;
-        $address = defined $uri ? Mail::Message::Field::Address->new(address => $uri->to) : undef;
+        $address = defined $uri
+                 ? Mail::Message::Field::Address->new(address => $uri->to)
+                 : undef;
     }
     else  # Don't understand life anymore :-(
     {   undef $address;
@@ -160,15 +169,18 @@ sub address()
     $self->{MMHL_address} = $address;
 }
 
+#------------------------------------------
+
 
 sub listname()
 {   my $self = shift;
-    exists $self->{MMHL_listname} and return $self->{MMHL_listname};
+    return $self->{MMHL_listname} if exists $self->{MMHL_listname};
 
     my $head = $self->head;
 
     # Some lists have a field with the name only
-    my $list = $head->get('List-ID') || $head->get('X-List') || $head->get('X-ML-Name');
+    my $list = $head->get('List-ID') || $head->get('X-List')
+            || $head->get('X-ML-Name');
 
     my $listname;
     if(defined $list)
@@ -183,6 +195,7 @@ sub listname()
 
 #------------------------------------------
 
+
 my $list_field_names
   = qr/ ^ (?: List|X-Envelope|X-Original ) - 
       | ^ (?: Precedence|Mailing-List|Approved-By ) $
@@ -196,15 +209,17 @@ sub isListGroupFieldName($) { $_[1] =~ $list_field_names }
 
 #------------------------------------------
 
+
 sub collectFields()
 {   my $self = shift;
-    my @names = map $_->name, $self->head->grepNames($list_field_names);
+    my @names = map { $_->name } $self->head->grepNames($list_field_names);
     $self->addFields(@names);
     @names;
 }
 
 #------------------------------------------
 
+
 sub details()
 {   my $self     = shift;
     my $type     = $self->type || 'Unknown';
