@@ -1,20 +1,16 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
+use strict;
 
 package Mail::Message::Head::Partial;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Mail::Message::Head::Complete';
 
-use strict;
-use warnings;
-
 use Scalar::Util 'weaken';
 
 
@@ -50,6 +46,8 @@ sub removeFieldsExcept(@)
     $self->cleanupOrderedFields;
 }
 
+#------------------------------------------
+
 
 sub removeResentGroups()
 {   my $self = shift;
@@ -69,6 +67,8 @@ sub removeResentGroups()
     $found;
 }
 
+#------------------------------------------
+
 
 sub removeListGroup()
 {   my $self = shift;
@@ -87,6 +87,8 @@ sub removeListGroup()
     $found;
 }
 
+#------------------------------------------
+
 
 sub removeSpamGroups()
 {   my $self = shift;
@@ -105,6 +107,8 @@ sub removeSpamGroups()
     $found;
 }
 
+#------------------------------------------
+
 
 sub cleanupOrderedFields()
 {   my $self = shift;
@@ -117,4 +121,6 @@ sub cleanupOrderedFields()
 #------------------------------------------
 
 
+#------------------------------------------
+
 1;
