@@ -1,20 +1,17 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
-
-package Mail::Message::Replace::MailHeader;
-use vars '$VERSION';
-$VERSION = '3.018_001';
-
-use base 'Mail::Message::Head::Complete';
 
 use strict;
 use warnings;
 
+package Mail::Message::Replace::MailHeader;
+use vars '$VERSION';
+$VERSION = '3.001';
+
+use base 'Mail::Message::Head::Complete';
+
 
 sub new(@)
 {   my $class = shift;
@@ -54,7 +51,7 @@ sub add($$)
 
 sub replace($$;$)
 {   my ($self, $tag, $line, $index) = @_;
-    $tag //= $line =~ s/^([^:]+)\:\s*// ? $1 : 'MISSING';
+    $line =~ s/^([^:]+)\:\s*// && ($tag = $1) unless defined $tag;
 
     my $field  = Mail::Message::Field::Fast->new($tag, $line);
     my @fields = $self->get($tag);
@@ -64,18 +61,15 @@ sub replace($$;$)
     $field;
 }
 
-#------------------
 
 sub get($;$)
 {   my $head = shift->head;
-    my @ret  = map $head->get(@_), @_;
+    my @ret  = map { $head->get(@_) } @_;
 
-       wantarray ? (map $_->unfoldedBody, @ret)
-     : @ret      ? $ret[0]->unfoldedBody
-     : undef;
+    if(wantarray) { return @ret ? map({$_->unfoldedBody} @ret) : () }
+    else          { return @ret ? $ret[0]->unfoldedBody : undef }
 }
 
-#------------------
 
 sub modify(;$)
 {   my $self = shift;
@@ -98,7 +92,7 @@ sub mail_from(;$)
 sub fold(;$)
 {   my $self = shift;
     my $wrap = @_ ? shift : $self->fold_length;
-    $_->setWrapLength($wrap) for $self->orderedFields;
+    $_->setWrapLength($wrap) foreach $self->orderedFields;
     $self;
 }
 
@@ -106,7 +100,7 @@ sub fold(;$)
 sub unfold(;$)
 {   my $self = shift;
     my @fields = @_ ? $self->get(shift) : $self->orderedFields;
-    $_->setWrapLength(100_000) for @fields;  # blunt approach
+    $_->setWrapLength(100_000) foreach @fields;  # blunt approach
     $self;
 }
 
@@ -132,7 +126,11 @@ sub extract($)
 
 sub read($)
 {   my ($self, $file) = @_;
-    my $parser = Mail::Box::Parser::Perl->new(filename => ('from file-handle '.ref $file), file => $file, trusted => 1);
+    my $parser = Mail::Box::Parser::Perl->new
+       ( filename  => ('from file-handle '.ref $file)
+       , file      => $file
+       , trusted   => 1
+       );
     $self->read($parser);
     $parser->close;
     $self;
