@@ -1,27 +1,22 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
-
-package Mail::Message::Replace::MailInternet;
-use vars '$VERSION';
-$VERSION = '3.018_001';
-
-use base 'Mail::Message';
 
 use strict;
 use warnings;
 
+package Mail::Message::Replace::MailInternet;
+use vars '$VERSION';
+$VERSION = '3.001';
+
+use base 'Mail::Message';
+
 use Mail::Box::FastScalar;
 use Mail::Box::Parser::Perl;
 use Mail::Message::Body::Lines;
 
-use IO::Handle ();
 use File::Spec;
-use Scalar::Util qw/blessed/;
 
 
 sub new(@)
@@ -51,15 +46,19 @@ sub init($)
 
 sub processRawData($$$)
 {   my ($self, $data, $get_head, $get_body) = @_;
-    $get_head || $get_body or return $self;
+    return $self unless $get_head || $get_body;
  
     my ($filename, $lines);
     if(ref $data eq 'ARRAY')
     {   $filename = 'array of lines';
         $lines    = $data;
     }
-    elsif(ref $data eq 'GLOB' || (blessed $data && $data->isa('IO::Handle')))
-    {   $filename = 'file (' . (ref $data) . ')';
+    elsif(ref $data eq 'GLOB')
+    {   $filename = 'file (GLOB)';
+        $lines    = [ <$data> ];
+    }
+    elsif(ref $data && $data->isa('IO::Handle'))
+    {   $filename = 'file ('.ref($data).')';
         $lines    = [ $data->getlines ];
     }
     else
@@ -67,24 +66,24 @@ sub processRawData($$$)
         return undef;
     }
 
-    @$lines or return;
+    return unless @$lines;
 
     my $buffer = join '', @$lines;
     my $file   = Mail::Box::FastScalar->new(\$buffer);
 
     my $parser = Mail::Box::Parser::Perl->new
-      ( filename  => $filename
-      , file      => $file
-      , trusted   => 1
-      );
+     ( filename  => $filename
+     , file      => $file
+     , trusted   => 1
+     );
 
     my $head;
     if($get_head)
-    {   my $from = $lines->[0] =~ m/^From / ? shift @$lines : undef;
+    {   my $from = substr($lines->[0], 0, 5) eq 'From ' ? shift @$lines : undef;
 
         my $head = $self->{MM_head_type}->new
           ( MailFrom   => $self->{MI_mail_from}
-          , Modify     => $self->{MI_modify}
+          , Modify => $self->{MI_modify}
           , FoldLength => $self->{MI_wrap}
           );
         $head->read($parser);
@@ -104,7 +103,7 @@ sub processRawData($$$)
 
 sub dup()
 {   my $self = shift;
-    (ref $self)->coerce($self->clone);
+    ref($self)->coerce($self->clone);
 }
 
 
@@ -112,6 +111,7 @@ sub empty() { shift->DESTROY }
 
 #--------------------------
 
+
 sub MailFrom(;$)
 {   my $self = shift;
     @_ ? ($self->{MI_mail_from} = shift) : $self->{MU_mail_from};
@@ -119,11 +119,12 @@ sub MailFrom(;$)
 
 #--------------------------
 
+
 sub read($@)
 {   my $thing = shift;
 
-    blessed $thing
-        or return $thing->SUPER::read(@_);  # Mail::Message behavior
+    return $thing->SUPER::read(@_)   # Mail::Message behavior
+        unless ref $thing;
 
     # Mail::Header emulation
     my $data = shift;
@@ -156,8 +157,12 @@ sub reply(@)
     my $home       = $ENV{HOME} || File::Spec->curdir;
     my $headtemp   = File::Spec->catfile($home, '.mailhdr');
 
-    if(open my $head, '<:raw', $headtemp)
-    {    my $parser = Mail::Box::Parser::Perl->new(filename => $headtemp, file => $head, trusted => 1);
+    if(open HEAD, '<:raw', $headtemp)
+    {    my $parser = Mail::Box::Parser::Perl->new
+           ( filename  => $headtemp
+           , file      => \*HEAD
+           , trusted   => 1
+           );
          $reply_head->read($parser);
          $parser->close;
     }
@@ -172,9 +177,9 @@ sub reply(@)
     my $head  = $self->head;
 
     $reply_head->add($_->clone)
-        for map $head->get($_), @$keep;
+        foreach map { $head->get($_) } @$keep;
 
-    $reply_head->reset($_) for @$exclude;
+    $reply_head->reset($_) foreach @$exclude;
 
     ref($self)->coerce($reply);
 }
@@ -182,7 +187,8 @@ sub reply(@)
 
 sub add_signature(;$)
 {   my $self     = shift;
-    my $filename = shift || File::Spec->catfile($ENV{HOME} || File::Spec->curdir, '.signature');
+    my $filename = shift
+       || File::Spec->catfile($ENV{HOME} || File::Spec->curdir, '.signature');
     $self->sign(File => $filename);
 }
 
@@ -198,7 +204,7 @@ sub sign(@)
     {   $sig = Mail::Message::Body->new(data => $sig);
     }
 
-    defined $sig or return;
+    return unless defined $sig;
  
     my $body = $self->decoded->stripSignature;
     my $set  = $body->concatenate($body, "-- \n", $sig);
@@ -265,8 +271,6 @@ sub delete(@)
     @_ ?  $self->head->delete(@_) : $self->SUPER::delete;
 }
 
-#------------
-
 
 sub body(@)
 {   my $self = shift;
@@ -331,8 +335,6 @@ sub smtpsend(@)
     $self->send(via => 'smtp', %args);
 }
 
-#------------
-
 
 sub as_mbox_string()
 {   my $self    = shift;
@@ -344,8 +346,6 @@ sub as_mbox_string()
     $buffer;
 }
 
-#------------
-
 
 BEGIN {
  no warnings;
@@ -362,8 +362,6 @@ sub isa($)
     $thing->SUPER::isa($class);
 }
 
-#------------
-
 
 sub coerce() { confess }
 
