@@ -1,20 +1,15 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+use strict;
 
 package Mail::Message::Test;
 use vars '$VERSION';
-$VERSION = '3.018_001';
+$VERSION = '3.001';
 
 use base 'Exporter';
 
-use strict;
-use warnings;
-
 use File::Copy 'copy';
 use List::Util 'first';
 use IO::File;            # to overrule open()
@@ -41,7 +36,8 @@ sub compare_message_prints($$$)
 {   my ($first, $second, $label) = @_;
 
     if($crlf_platform)
-    {   s/Content-Length: (\d+)/Content-Length: <removed>/g for $first, $second;
+    {   $first  =~ s/Content-Length: (\d+)/Content-Length: <removed>/g;
+        $second =~ s/Content-Length: (\d+)/Content-Length: <removed>/g;
     }
 
     is($first, $second, $label);
