@@ -1,21 +1,17 @@
-# Copyrights 2001-2025 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-# This code is part of distribution Mail-Message.  Meta-POD processed with
-# OODoc into POD and HTML manual-pages.  See README.md
-# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
-
-package Mail::Reporter;
-use vars '$VERSION';
-$VERSION = '3.018_001';
-
-
 use strict;
 use warnings;
 
+package Mail::Reporter;
+use vars '$VERSION';
+$VERSION = '3.001';
+
+
 use Carp;
-use Scalar::Util qw(dualvar blessed);
+use Scalar::Util 'dualvar';
 
 
 my @levelname = (undef, qw(DEBUG NOTICE PROGRESS WARNING ERROR NONE INTERNAL));
@@ -29,10 +25,10 @@ for(my $l = 1; $l < @levelname; $l++)
 sub new(@)
 {   my $class = shift;
 #confess "Parameter list has odd length: @_" if @_ % 2;
-    (bless +{MR_log => 1, MR_trace => 1}, $class)->init({@_});
+    (bless {MR_log => 1, MR_trace => 1}, $class)->init({@_});
 }
 
-my ($default_log, $default_trace, $trace_callback);
+my($default_log, $default_trace, $trace_callback);
 sub init($)
 {   my ($self, $args) = @_;
     $self->{MR_log}   = $levelprio{$args->{log}   || $default_log};
@@ -42,12 +38,6 @@ sub init($)
 
 #------------------------------------------
 
-sub logSettings()
-{  my $self = shift;
-   (log => $self->{MR_log}, trace => $self->{MR_trace});
-}
-
-#------------------------------------------
 
 sub _trace_warn($$$)
 {   my ($who, $level, $text) = @_;
@@ -84,6 +74,7 @@ sub defaultTrace(;$$)
 
 __PACKAGE__->defaultTrace('WARNINGS');
 
+#------------------------------------------
 
 
 sub trace(;$$)
@@ -99,6 +90,7 @@ sub trace(;$$)
     $self->{MR_trace} = $prio;
 }
 
+#------------------------------------------
 
 
 # Implementation detail: the Mail::Box::Parser::C code avoids calls back
@@ -107,77 +99,99 @@ sub trace(;$$)
 # whether or not to display it.
 
 sub log(;$@)
-{   if(blessed $_[0])   # instance call
-    {   my $self = shift;
-        @_ or return $self->logPriority($self->{MR_log});
+{   my $thing = shift;
+
+    if(ref $thing)   # instance call
+    {   return $thing->logPriority($thing->{MR_log})
+            unless @_;
 
         my $level = shift;
-        my $prio  = $levelprio{$level} or croak "Unknown log-level $level";
+        my $prio  = $levelprio{$level}
+            or croak "Unknown log-level $level";
 
-        @_ or return $self->{MR_log} = $prio;
+        return $thing->{MR_log} = $prio
+            unless @_;
 
         my $text    = join '', @_;
-        $trace_callback->($self, $level, $text)
-            if $prio >= $self->{MR_trace};
+        $trace_callback->($thing, $level, $text)
+            if $prio >= $thing->{MR_trace};
+use Carp;
+$thing->{MR_trace} or confess;
 
-        push @{$self->{MR_report}[$prio]}, $text
-            if $prio >= $self->{MR_log};
+        push @{$thing->{MR_report}[$prio]}, $text
+            if $prio >= $thing->{MR_log};
+    }
+    else             # class method
+    {   my $level = shift;
+        my $prio  = $levelprio{$level}
+            or croak "Unknown log-level $level";
 
-		return $self;
+        $trace_callback->($thing, $level, join('',@_)) 
+           if $prio >= $default_trace;
     }
 
-    # class method
-	my ($class, $level) = (shift, shift);
-    my $prio  = $levelprio{$level} or croak "Unknown log-level $level";
-
-    $trace_callback->($class, $level, join('', @_)) 
-        if $prio >= $default_trace;
-
-    $class;
+    $thing;
 }
 
 
+#------------------------------------------
+
+
 sub report(;$)
 {   my $self    = shift;
     my $reports = $self->{MR_report} || return ();
 
     if(@_)
     {   my $level = shift;
-        my $prio  = $levelprio{$level} or croak "Unknown report level $level.";
+        my $prio  = $levelprio{$level}
+            or croak "Unknown report level $level.";
+
         return $reports->[$prio] ? @{$reports->[$prio]} : ();
     }
 
     my @reports;
     for(my $prio = 1; $prio < @$reports; $prio++)
-    {   $reports->[$prio] or next;
+    {   next unless $reports->[$prio];
         my $level = $levelname[$prio];
-        push @reports, map +[ $level, $_ ], @{$reports->[$prio]};
+        push @reports, map { [ $level, $_ ] } @{$reports->[$prio]};
     }
 
     @reports;
 }
 
+#-------------------------------------------
+
 
 sub addReport($)
 {   my ($self, $other) = @_;
-    my $from = $other->{MR_report} || return ();
+    my $reports = $other->{MR_report} || return ();
 
-    for(my $prio = 1; $prio < @$from; $prio++)
-    {   my $take = $from->[$prio] or next;
-		push @{$self->{MR_report}[$prio]}, @$take;
+    for(my $prio = 1; $prio < @$reports; $prio++)
+    {   push @{$self->{MR_report}[$prio]}, @{$reports->[$prio]}
+            if exists $reports->[$prio];
     }
     $self;
 }
     
+#-------------------------------------------
+
 
 sub reportAll(;$)
 {   my $self = shift;
-    map +[ $self, @$_ ], $self->report(@_);
+    map { [ $self, @$_ ] } $self->report(@_);
 }
 
+#-------------------------------------------
+
+
+sub errors(@)   {shift->report('ERRORS')}
+
+#-------------------------------------------
+
 
 sub warnings(@) {shift->report('WARNINGS')}
-sub errors(@)   {shift->report('ERRORS')}
+
+#-------------------------------------------
 
 
 sub notImplemented(@)
@@ -189,18 +203,30 @@ sub notImplemented(@)
     confess "Please warn the author, this shouldn't happen.";
 }
 
+#------------------------------------------
+
 
 sub logPriority($)
 {   my $level = $levelprio{$_[1]} or return undef;
     dualvar $level, $levelname[$level];
 }
 
+#-------------------------------------------
+
+
+sub logSettings()
+{  my $self = shift;
+   (log => $self->{MR_log}, trace => $self->{MR_trace});
+}
+
+#-------------------------------------------
+
 
 sub AUTOLOAD(@)
 {   my $thing   = shift;
     our $AUTOLOAD;
-    my $class  = ref $thing || $thing;
-    my $method = $AUTOLOAD =~ s/^.*\:\://r;
+    my $class   = ref $thing || $thing;
+    (my $method = $AUTOLOAD) =~ s/^.*\:\://;
 
     $Carp::MaxArgLen=20;
     confess "Method $method() is not defined for a $class.\n";
@@ -208,6 +234,10 @@ sub AUTOLOAD(@)
 
 #-------------------------------------------
 
-sub DESTROY { shift }
+
+#-------------------------------------------
+
+
+sub DESTROY {shift}
 
 1;
